@@ -3,7 +3,7 @@ Settings for askbot data display and entry
 """
 from django.utils.translation import ugettext_lazy as _
 from askbot.conf.settings_wrapper import settings
-from askbot.deps import livesettings
+from livesettings import values as livesettings
 from askbot import const
 from askbot.conf.super_groups import DATA_AND_FORMATTING
 
