@@ -2,7 +2,7 @@
 from django.utils.translation import ugettext_lazy as _
 from askbot.conf.settings_wrapper import settings
 from askbot.conf.super_groups import LOGIN_USERS_COMMUNICATION
-from askbot.deps import livesettings
+from livesettings import values as livesettings
 
 GROUP_SETTINGS = livesettings.ConfigurationGroup(
     'GROUP_SETTINGS',
