@@ -5,7 +5,8 @@ and the application available for the templates
 import sys
 import json
 from django.conf import settings
-from django.core.urlresolvers import reverse
+from django.middleware import csrf
+from django.urls import reverse
 
 import askbot
 from askbot import api
@@ -14,11 +15,39 @@ from askbot import const
 from askbot.conf import settings as askbot_settings
 from askbot.search.state_manager import SearchState
 from askbot.utils import url_utils
-from askbot.utils.csrf import get_or_create_csrf_token
 from askbot.utils.slug import slugify
 from askbot.utils.html import site_url
 from askbot.utils.translation import get_language
 
+def make_group_list():
+    if not askbot_settings.GROUPS_ENABLED:
+        return []
+    # calculate context needed to list all the groups
+    def _get_group_url(group):
+        """calculates url to the group based on its id and name"""
+        group_slug = slugify(group['name'])
+        return reverse(
+            'users_by_group',
+            kwargs={'group_id': group['id'], 'group_slug': group_slug})
+
+    # load id's and names of all groups
+    global_group = models.Group.objects.get_global_group()
+    groups = models.Group.objects.exclude_personal()
+    groups = groups.exclude(id=global_group.id)
+    groups_data = list(groups.values('id', 'name'))
+
+    # sort groups_data alphanumerically, but case-insensitive
+    groups_data = sorted(groups_data, key=lambda x: x['name'].lower())
+
+    # insert data for the global group at the first position
+    groups_data.insert(0, {'id': global_group.id, 'name': global_group.name})
+
+    # build group_list for the context
+    group_list = list()
+    for group in groups_data:
+        link = _get_group_url(group)
+        group_list.append({'name': group['name'], 'link': link})
+    return group_list
 
 def application_settings(request):
     """The context processor function"""
@@ -50,9 +79,9 @@ def application_settings(request):
 
     if my_settings['EDITOR_TYPE'] == 'tinymce':
         tinymce_plugins = settings.TINYMCE_DEFAULT_CONFIG.get('plugins', '').split(',')
-        my_settings['TINYMCE_PLUGINS'] = map(lambda v: v.strip(), tinymce_plugins)
+        my_settings['TINYMCE_PLUGINS'] = [v.strip() for v in tinymce_plugins]
         my_settings['TINYMCE_EDITOR_DESELECTOR'] = settings.TINYMCE_DEFAULT_CONFIG['editor_deselector']
-        my_settings['TINYMCE_CONFIG_JSON'] = simplejson.dumps(settings.TINYMCE_DEFAULT_CONFIG)
+        my_settings['TINYMCE_CONFIG_JSON'] = json.dumps(settings.TINYMCE_DEFAULT_CONFIG)
     else:
         my_settings['TINYMCE_PLUGINS'] = []
         my_settings['TINYMCE_EDITOR_DESELECTOR'] = ''
@@ -71,11 +100,11 @@ def application_settings(request):
 
     need_scope_links = askbot_settings.ALL_SCOPE_ENABLED or \
         askbot_settings.UNANSWERED_SCOPE_ENABLED or \
-        (request.user.is_authenticated() and askbot_settings.FOLLOWED_SCOPE_ENABLED)
+        (request.user.is_authenticated and askbot_settings.FOLLOWED_SCOPE_ENABLED)
 
     context = {
         'base_url': site_url(''),
-        'csrf_token': get_or_create_csrf_token(request),
+        'csrf_token': csrf.get_token(request),
         'empty_search_state': SearchState.get_empty(),
         'min_search_word_length': min_search_word_length,
         'current_language_code': current_language,
@@ -87,39 +116,11 @@ def application_settings(request):
 
     use_askbot_login = 'askbot.deps.django_authopenid' in settings.INSTALLED_APPS
     my_settings['USE_ASKBOT_LOGIN_SYSTEM'] = use_askbot_login
-    if use_askbot_login and request.user.is_anonymous():
+    if use_askbot_login and request.user.is_anonymous:
         from askbot.deps.django_authopenid import context as login_context
         context.update(login_context.login_context(request))
 
-    if askbot_settings.GROUPS_ENABLED:
-        # calculate context needed to list all the groups
-        def _get_group_url(group):
-            """calculates url to the group based on its id and name"""
-            group_slug = slugify(group['name'])
-            return reverse(
-                'users_by_group',
-                kwargs={'group_id': group['id'], 'group_slug': group_slug})
-
-        # load id's and names of all groups
-        global_group = models.Group.objects.get_global_group()
-        groups = models.Group.objects.exclude_personal()
-        groups = groups.exclude(id=global_group.id)
-        groups_data = list(groups.values('id', 'name'))
-
-        # sort groups_data alphanumerically, but case-insensitive
-        groups_data = sorted(
-            groups_data,
-            lambda x, y: cmp(x['name'].lower(), y['name'].lower()))
-
-        # insert data for the global group at the first position
-        groups_data.insert(0, {'id': global_group.id, 'name': global_group.name})
-
-        # build group_list for the context
-        group_list = list()
-        for group in groups_data:
-            link = _get_group_url(group)
-            group_list.append({'name': group['name'], 'link': link})
-        context['group_list'] = json.dumps(group_list)
+    context['group_list'] = json.dumps(make_group_list())
 
     if askbot_settings.EDITOR_TYPE == 'tinymce':
         from tinymce.widgets import TinyMCE
