@@ -78,7 +78,7 @@ class LoginProviderField(forms.CharField):
         if value in providers:
             return value
         else:
-            error_message = u'unknown provider name %s' % value
+            error_message = 'unknown provider name %s' % value
             logging.critical(error_message)
             raise forms.ValidationError(error_message)
 
@@ -262,7 +262,7 @@ class LoginForm(forms.Form):
                 _('Please, enter your new password')
             )
             field_set = set(('new_password', 'new_password_retyped'))
-            if field_set.issubset(self.cleaned_data.keys()):
+            if field_set.issubset(list(self.cleaned_data.keys())):
                 new_password = self.cleaned_data[
                                                 'new_password'
                                             ].strip()
@@ -377,10 +377,10 @@ class ChangeEmailForm(forms.Form):
             except User.DoesNotExist:
                 return self.cleaned_data['email']
             except User.MultipleObjectsReturned:
-                raise forms.ValidationError(u'There is already more than one \
+                raise forms.ValidationError('There is already more than one \
                     account registered with that e-mail address. Please try \
                     another.')
-            raise forms.ValidationError(u'This email is already registered \
+            raise forms.ValidationError('This email is already registered \
                 in our database. Please choose another.')
 
 
