@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 import cgi
 import functools
-import httplib
+import http.client
 import re
-import urllib
-import urlparse
+import urllib.request, urllib.parse, urllib.error
+import urllib.parse
 from collections import OrderedDict
 from askbot.utils.html import site_url
 from askbot.utils.functions import format_setting_name
@@ -16,12 +16,13 @@ from openid import store as openid_store
 import oauth2 as oauth # OAuth1 protocol
 from django.db.models.query import Q
 from django.conf import settings
-from django.core.urlresolvers import reverse
-import simplejson
+from django.urls import reverse
+import json
 from django.utils.translation import ugettext as _
 from django.core.exceptions import ImproperlyConfigured
 from askbot.deps.django_authopenid import providers
 from askbot.deps.django_authopenid.exceptions import OAuthError
+from functools import reduce
 
 try:
     from hashlib import md5
@@ -36,8 +37,8 @@ try:
 except:
     from yadis import xri
 
-import time, base64, hashlib, operator, logging
-from models import Association, Nonce
+import time, base64, hmac, hashlib, operator, logging
+from .models import Association, Nonce
 
 __all__ = ['OpenID', 'DjangoOpenIDStore', 'from_openid_response']
 
@@ -186,10 +187,10 @@ def get_provider_name_by_endpoint(openid_url):
     Pair the openid_url with endpoint urls defined for different openid
     providers. Returns None if no matching url was found.
     """
-    parsed_uri = urlparse.urlparse(openid_url)
+    parsed_uri = urllib.parse.urlparse(openid_url)
     base_url = '{uri.scheme}://{uri.netloc}'.format(uri=parsed_uri)
     providers = get_enabled_login_providers()
-    for provider_data in providers.itervalues():
+    for provider_data in providers.values():
         openid_url_match = (provider_data['type'].startswith('openid') and
             provider_data['openid_endpoint'] is not None and
             provider_data['openid_endpoint'].startswith(base_url))
@@ -226,7 +227,7 @@ def filter_enabled_providers(data):
     the input dictionary
     """
     delete_list = list()
-    for provider_key, provider_settings in data.items():
+    for provider_key, provider_settings in list(data.items()):
         name = provider_settings['name']
         if not is_login_method_enabled(name):
             delete_list.append(provider_key)
@@ -271,7 +272,7 @@ class LoginMethod(object):
             )
 
         self.name = getattr(self.mod, 'NAME', None)
-        if self.name is None or not isinstance(self.name, basestring):
+        if self.name is None or not isinstance(self.name, str):
             raise ImproperlyConfigured(
                 '%s.NAME is required as a string parameter' % self.mod_path
             )
@@ -281,7 +282,7 @@ class LoginMethod(object):
             )
 
         self.display_name = getattr(self.mod, 'DISPLAY_NAME', None)
-        if self.display_name is None or not isinstance(self.display_name, basestring):
+        if self.display_name is None or not isinstance(self.display_name, str):
             raise ImproperlyConfigured(
                 '%s.DISPLAY_NAME is required as a string parameter' % self.mod_path
             )
@@ -380,7 +381,7 @@ def add_custom_provider(func):
             mod = LoginMethod(login_module_path)
             if mod.is_major != func.is_major:
                 return providers#only patch the matching provider set
-            providers.insert(mod.order_number - 1, mod.name, mod.as_dict())
+            providers[mod.name] = mod.as_dict()
         return providers
     return wrapper
 
@@ -454,10 +455,34 @@ def get_enabled_major_login_providers():
             'extra_token_name': _('%(login_name)s username') % context_dict
         }
 
-    def get_facebook_user_id(client):
-        """returns facebook user id given the access token"""
-        profile = client.request('me')
-        return profile['id']
+    def get_user_id_from_resource_endpoint(session, provider, get_user_id=None):
+        if get_user_id is None:
+            get_user_id = lambda data:data['id']
+        response = session.get(provider['resource_endpoint'])  # fetch data
+        user_data = provider['response_parser'](response.text) # parse json
+        return get_user_id(user_data)                          # get user id
+
+    def get_facebook_user_id(session, facebook):
+        return get_user_id_from_resource_endpoint(session, facebook)
+
+    def get_yammer_user_id(session, yammer):
+        return get_user_id_from_resource_endpoint(session, yammer,
+                                get_user_id=lambda data: data['user']['id'])
+
+    def get_windows_live_user_id(session, wlive):
+        return get_user_id_from_resource_endpoint(session, wlive,
+                                get_user_id=lambda data: data['user_id'])
+
+    def get_microsoft_azure_user_id(session, azure):
+        return get_user_id_from_resource_endpoint(session, azure,
+                                get_user_id=lambda data: data['id'])
+
+    def get_google_user_id(session, google):
+        return get_user_id_from_resource_endpoint(session, google,
+                                get_user_id=lambda data: data['id'])
+
+    def get_github_user_id(session, github):
+        return get_user_id_from_resource_endpoint(session, github)
 
     if askbot_settings.FACEBOOK_KEY and askbot_settings.FACEBOOK_SECRET:
         data['facebook'] = {
@@ -466,11 +491,11 @@ def get_enabled_major_login_providers():
             'type': 'oauth2',
             'auth_endpoint': 'https://www.facebook.com/v3.2/dialog/oauth/',
             'token_endpoint': 'https://graph.facebook.com/v3.2/oauth/access_token',
-            'resource_endpoint': 'https://graph.facebook.com/v3.2/',
+            'resource_endpoint': 'https://graph.facebook.com/v3.2/me',
             'icon_media_path': 'images/jquery-openid/facebook.gif',
             'get_user_id_function': get_facebook_user_id,
-            'response_parser': lambda data: simplejson.loads(data),
-            'scope': ['email',],
+            'response_parser': json.loads,
+            'extra_auth_params': {'scope': ['email']},
         }
 
     if askbot_settings.YAMMER_KEY and askbot_settings.YAMMER_SECRET:
@@ -482,8 +507,8 @@ def get_enabled_major_login_providers():
             'token_endpoint': 'https://www.yammer.com/oauth2/access_token',
             'resource_endpoint': 'https://www.yammer.com/api/v1/users/current.json',
             'icon_media_path': 'images/jquery-openid/yammer.png',
-            'get_user_id_function': lambda data: data.user['id'],
-            'response_parser': lambda data: simplejson.loads(data),
+            'get_user_id_function': get_yammer_user_id,
+            'response_parser': json.loads,
         }
 
     if askbot_settings.WINDOWS_LIVE_KEY and askbot_settings.WINDOWS_LIVE_SECRET:
@@ -495,22 +520,11 @@ def get_enabled_major_login_providers():
             'token_endpoint': 'https://login.live.com/oauth20_token.srf',
             'resource_endpoint': 'https://apis.live.net/v5.0/me',
             'icon_media_path': 'images/jquery-openid/windows-live.png',
-            'get_user_id_function': lambda data: data.user_id,
-            'response_parser': lambda data: simplejson.loads(data),
+            'get_user_id_function': get_windows_live_user_id,
+            'response_parser': json.loads,
             'extra_auth_params': {'scope': ('wl.basic',)},
         }
 
-    def get_microsoft_azure_user_id(client):
-        conn = httplib.HTTPSConnection('graph.microsoft.com')
-        headers = {
-            'Authorization' : 'Bearer {0}'.format(client.access_token),
-            'Accept' : 'application/json',
-        }
-        conn.request('GET', '/v1.0/me', '', headers)
-        response = conn.getresponse()
-        profile = simplejson.loads(response.read())
-        return profile['id']
-
     if askbot_settings.MICROSOFT_AZURE_KEY and askbot_settings.MICROSOFT_AZURE_SECRET:
         data['microsoft-azure'] = {
             'name': 'microsoft-azure',
@@ -518,10 +532,10 @@ def get_enabled_major_login_providers():
             'type': 'oauth2',
             'auth_endpoint': 'https://login.microsoftonline.com/common/oauth2/v2.0/authorize',
             'token_endpoint': 'https://login.microsoftonline.com/common/oauth2/v2.0/token',
-            'resource_endpoint': 'https://graph.microsoft.com/v1.0/',
+            'resource_endpoint': 'https://graph.microsoft.com/v1.0/me',
             'icon_media_path': 'images/jquery-openid/microsoft-azure.png',
             'get_user_id_function': get_microsoft_azure_user_id,
-            'response_parser': lambda data: simplejson.loads(data),
+            'response_parser': json.loads,
             'extra_auth_params': {'scope': ('User.Read',),},
         }
 
@@ -570,8 +584,7 @@ def get_enabled_major_login_providers():
         client = oauth.Client(consumer, token=token)
         url = 'https://identi.ca/api/account/verify_credentials.json'
         response, content = client.request(url, 'GET')
-        json = simplejson.loads(content)
-        return json['id']
+        return json.loads(content)['id']
 
     if askbot_settings.IDENTICA_KEY and askbot_settings.IDENTICA_SECRET:
         data['identi.ca'] = {
@@ -620,9 +633,6 @@ def get_enabled_major_login_providers():
             'get_user_id_function': get_linked_in_user_id
         }
 
-    def get_google_user_id(client):
-        return client.request('me')['id']
-
     if askbot_settings.GOOGLE_PLUS_KEY and askbot_settings.GOOGLE_PLUS_SECRET:
         data['google-plus'] = {
             'name': 'google-plus',
@@ -630,7 +640,7 @@ def get_enabled_major_login_providers():
             'type': 'oauth2',
             'auth_endpoint': 'https://accounts.google.com/o/oauth2/auth',
             'token_endpoint': 'https://accounts.google.com/o/oauth2/token',
-            'resource_endpoint': 'https://www.googleapis.com/plus/v1/people/',
+            'resource_endpoint': 'https://www.googleapis.com/plus/v1/people/me',
             'icon_media_path': 'images/jquery-openid/google.gif',
             'get_user_id_function': get_google_user_id,
             'extra_auth_params': {'scope': ('profile', 'email', 'openid'), 'openid.realm': askbot_settings.APP_URL}
@@ -674,6 +684,18 @@ def get_enabled_major_login_providers():
         'icon_media_path': 'images/jquery-openid/openid.gif',
         'openid_endpoint': None,
     }
+    data['github'] = {
+        'name': 'github',
+        'display_name': 'GitHub',
+        'type': 'oauth2',
+        'auth_endpoint': 'https://github.com/login/oauth/authorize',
+        'token_endpoint': 'https://github.com/login/oauth/access_token',
+        'resource_endpoint': 'https://api.github.com/user',
+        'icon_media_path': 'images/jquery-openid/GitHub_Logo.png',
+        'get_user_id_function': get_github_user_id,
+        'response_parser': json.loads,
+    }
+
     if askbot_settings.SIGNIN_OPENSTACKID_ENABLED and askbot_settings.OPENSTACKID_ENDPOINT_URL:
         data['openstackid'] = {
             'name': 'openstackid',
@@ -775,7 +797,7 @@ get_enabled_minor_login_providers = add_custom_provider(get_enabled_minor_login_
 def have_enabled_federated_login_methods():
     providers = get_enabled_major_login_providers()
     providers.update(get_enabled_minor_login_providers())
-    provider_types = [provider['type'] for provider in providers.values()]
+    provider_types = [provider['type'] for provider in list(providers.values())]
     for provider_type in provider_types:
         if provider_type.startswith('openid') or provider_type == 'oauth':
             return True
@@ -796,7 +818,7 @@ def get_the_only_login_provider():
     """
     providers = get_enabled_login_providers()
     if len(providers) == 1:
-        provider = providers.values()[0]
+        provider = list(providers.values())[0]
         if not provider_requires_login_page(provider):
             return provider
     return None
@@ -814,7 +836,7 @@ def set_login_provider_tooltips(provider_dict, active_provider_names = None):
     depending on the type of provider and whether or not it's one of
     currently used
     """
-    for provider in provider_dict.values():
+    for provider in list(provider_dict.values()):
         if active_provider_names:
             if provider['name'] in active_provider_names:
                 if provider['type'] == 'password':
@@ -891,6 +913,9 @@ def get_oauth_parameters(provider_name):
     elif provider_name == 'microsoft-azure':
         consumer_key = askbot_settings.MICROSOFT_AZURE_KEY
         consumer_secret = askbot_settings.MICROSOFT_AZURE_SECRET
+    elif provider_name == 'github':
+        consumer_key = askbot_settings.GITHUB_KEY
+        consumer_secret = askbot_settings.GITHUB_SECRET
     elif provider_name != 'mediawiki':
         raise ValueError('unexpected oauth provider %s' % provider_name)
 
@@ -932,7 +957,7 @@ class OAuthConnection(object):
 
         url, params = url.split('?')
         if params:
-            kv = map(lambda v: v.split('='), params.split('&'))
+            kv = [v.split('=') for v in params.split('&')]
             if kv:
                 #kv must be list of two-element arrays
                 params = dict(kv)
@@ -945,11 +970,11 @@ class OAuthConnection(object):
     @classmethod
     def format_request_params(cls, params):
         #convert to tuple
-        params = params.items()
+        params = list(params.items())
         #sort lexicographically by key
-        params = sorted(params, cmp=lambda x, y: cmp(x[0], y[0]))
+        params = sorted(params, key=lambda x: x[0])
         #urlencode the tuples
-        return urllib.urlencode(params)
+        return urllib.parse.urlencode(params)
 
     @classmethod
     def normalize_url_and_params(cls, url, params):
@@ -1068,19 +1093,17 @@ class OAuthConnection(object):
 
 def get_oauth2_starter_url(provider_name, csrf_token):
     """returns redirect url for the oauth2 protocol for a given provider"""
-    from sanction.client import Client
+    from requests_oauthlib.oauth2_session import OAuth2Session
 
     providers = get_enabled_login_providers()
     params = providers[provider_name]
     client_id = getattr(askbot_settings, format_setting_name(provider_name) + '_KEY')
     redirect_uri = site_url(reverse('user_complete_oauth2_signin'))
-    client = Client(
-        auth_endpoint=params['auth_endpoint'],
-        client_id=client_id,
-        redirect_uri=redirect_uri
-    )
-    
-    return client.auth_uri(state=csrf_token, **params.get('extra_auth_params', {}))
+    session = OAuth2Session(client_id, redirect_uri=redirect_uri, state=csrf_token)
+
+    url, csrf = session.authorization_url(params['auth_endpoint'],  **params.get('extra_auth_params', {}))
+    return url.encode('utf-8')
+
 
 
 def ldap_check_password(username, password):
@@ -1091,14 +1114,14 @@ def ldap_check_password(username, password):
         ldap_session.unbind_s()
         return True
     except ldap.LDAPError as e:
-        logging.critical(unicode(e))
+        logging.critical(str(e))
         return False
 
 
 def mozilla_persona_get_email_from_assertion(assertion):
-    conn = httplib.HTTPSConnection('verifier.login.persona.org')
-    parsed_url = urlparse.urlparse(askbot_settings.APP_URL)
-    params = urllib.urlencode({
+    conn = http.client.HTTPSConnection('verifier.login.persona.org')
+    parsed_url = urllib.parse.urlparse(askbot_settings.APP_URL)
+    params = urllib.parse.urlencode({
                     'assertion': assertion,
                     'audience': parsed_url.scheme + '://' + parsed_url.netloc
                 })
@@ -1106,12 +1129,12 @@ def mozilla_persona_get_email_from_assertion(assertion):
     conn.request('POST', '/verify', params, headers)
     response = conn.getresponse()
     if response.status == 200:
-        data = simplejson.loads(response.read())
+        data = json.loads(response.read())
         email = data.get('email')
         if email:
             return email
         else:
-            message = unicode(data)
+            message = str(data)
             message += '\nMost likely base url in /settings/QA_SITE_SETTINGS/ is incorrect'
             raise ImproperlyConfigured(message)
     #todo: nead more feedback to help debug fail cases
@@ -1124,7 +1147,7 @@ def google_gplus_get_openid_data(client):
         token = token.encode('ascii')
         token = token + '='*(4 - len(token)%4)
         token = base64.urlsafe_b64decode(token)
-        data = simplejson.loads(token)
+        data = json.loads(token)
         return data.get('openid_id'), data.get('email')
     return None
 
