@@ -41,17 +41,17 @@ from askbot.conf import settings as askbot_settings
 from django.contrib.auth.models import User
 from django.contrib.auth.decorators import login_required
 from django.contrib.auth import authenticate
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.shortcuts import render
 from django.template.loader import get_template
 from django.views.decorators import csrf
 from django.utils import timezone
-from django.utils.encoding import smart_unicode
+from django.utils.encoding import smart_text
 from askbot.utils.functions import generate_random_key, encode_jwt
 from django.utils.html import escape
 from django.utils.translation import ugettext as _
 from django.utils.safestring import mark_safe
-import simplejson
+import json
 from askbot.mail.messages import AccountActivation, AccountRecovery
 from askbot.utils import decorators as askbot_decorators
 from askbot.utils.functions import format_setting_name
@@ -62,8 +62,8 @@ from askbot.deps.django_authopenid.providers import discourse
 from askbot.deps.django_authopenid.exceptions import OAuthError
 from askbot.middleware.anon_user import connect_messages_to_anon_user
 from askbot.utils.loading import load_module
-from sanction.client import Client as OAuth2Client
-from urlparse import urlparse
+from requests_oauthlib.oauth2_session import OAuth2Session
+from urllib.parse import urlparse
 
 from openid.consumer.consumer import Consumer, \
     SUCCESS, CANCEL, FAILURE, SETUP_NEEDED
@@ -76,14 +76,14 @@ except ImportError:
     from yadis import xri
 
 try:
-    from xmlrpclib import Fault as WpFault
+    from xmlrpc.client import Fault as WpFault
     from wordpress_xmlrpc import Client
     from wordpress_xmlrpc.methods.users import GetUserInfo
 except ImportError:
     pass
 
 
-import urllib
+import urllib.request, urllib.parse, urllib.error
 from askbot import forms as askbot_forms
 from askbot.deps.django_authopenid import util
 from askbot.deps.django_authopenid.models import UserAssociation, UserEmailVerifier
@@ -91,7 +91,7 @@ from askbot.deps.django_authopenid import forms
 from askbot.deps.django_authopenid.backends import AuthBackend
 import logging
 from askbot.utils.forms import get_next_url, get_next_jwt
-from askbot.utils.http import get_request_info
+from askbot.utils.http import get_request_info, get_request_params
 from askbot.signals import user_logged_in, user_registered
 
 
@@ -220,7 +220,7 @@ def ask_openid(
         auth_request = consumer.begin(openid_url)
     except DiscoveryFailure:
         openid_url = cgi.escape(openid_url)
-        msg = _(u"OpenID %(openid_url)s is invalid" % {'openid_url':openid_url})
+        msg = _("OpenID %(openid_url)s is invalid" % {'openid_url':openid_url})
         logging.debug(msg)
         return signin_failure(request, msg)
 
@@ -237,7 +237,7 @@ def not_authenticated(func):
     """ decorator that redirect user to next page if
     he/she is already logged in."""
     def decorated(request, *args, **kwargs):
-        if request.user.is_authenticated():
+        if request.user.is_authenticated:
             return HttpResponseRedirect(get_next_url(request))
         return func(request, *args, **kwargs)
     return decorated
@@ -248,12 +248,11 @@ def complete_discourse_signin(request):
     discourse_login_session = request.session.get('discourse_login')
     nonce = discourse_login_session.get('nonce', None)
     from askbot.deps.django_authopenid.providers import discourse
-    form = discourse.DiscourseSsoForm(request.REQUEST, nonce=nonce)
+    form = discourse.DiscourseSsoForm(get_request_params(request), nonce=nonce)
     next_url = discourse_login_session.get('success_url', reverse('questions'))
     if not form.is_valid():
         # if form is invalid - show login screen with error message
-        info = unicode(form.errors).encode('utf-8')
-        logging.error('Could not aunenticate via a Discourse site %s', info)
+        logging.error('Could not aunenticate via a Discourse site %s', str(form.errors))
         login_form = forms.LoginForm(initial={'next': next_url})
         message = _('Unfortunately, there was some problem logging in via the Discourse site')
         request.user.message_set.create(message=message)
@@ -303,22 +302,22 @@ def complete_oauth2_signin(request):
             name_token + '_SECRET',
         )
 
-    client = OAuth2Client(
-            token_endpoint=params['token_endpoint'],
-            resource_endpoint=params['resource_endpoint'],
+    session = OAuth2Session(
             redirect_uri=site_url(reverse('user_complete_oauth2_signin')),
             client_id=client_id,
-            client_secret=client_secret,
-            token_transport=params.get('token_transport', None)
+            auto_refresh_url=params['token_endpoint'],
+            token_updater = params.get('token_transport', None)
         )
 
-    client.request_token(
+    session.fetch_token(
+        params['token_endpoint'],
         code=request.GET['code'],
-        parser=params.get('response_parser', None)
+        client_secret=client_secret
     )
 
+
     #todo: possibly set additional parameters here
-    user_id = params['get_user_id_function'](client)
+    user_id = params['get_user_id_function'](session, params)
 
     user = authenticate(
                 user_identifier=user_id,
@@ -332,13 +331,14 @@ def complete_oauth2_signin(request):
     request.session['username'] = ''#todo: pull from profile
 
     if provider_name == 'facebook':
-        profile = client.request("me")
+        response = session.get(params['resource_endpoint'])
+        profile = params['response_parser'](response.text)
         request.session['email'] = profile.get('email', '')
         request.session['username'] = profile.get('username', '')
     elif provider_name == 'google-plus' and user is None:
         #todo: factor this out into separate function
         #attempt to migrate user from the old OpenId protocol
-        openid_url, email = util.google_gplus_get_openid_data(client)
+        openid_url, email = util.google_gplus_get_openid_data(session)
         if openid_url:
             msg_tpl = 'trying to migrate user from OpenID %s to g-plus %s'
             logging.critical(msg_tpl, str(openid_url), str(user_id))
@@ -510,7 +510,7 @@ def signin(request, template_name='authopenid/signin.html'):
     logging.debug('next url is %s' % next_url)
 
     if askbot_settings.ALLOW_ADD_REMOVE_LOGIN_METHODS == False \
-        and request.user.is_authenticated():
+        and request.user.is_authenticated:
         return HttpResponseRedirect(next_url)
 
     next_jwt = encode_jwt({'next_url': next_url})
@@ -601,7 +601,7 @@ def signin(request, template_name='authopenid/signin.html'):
                             #for external login sites
                             return HttpResponseRedirect(next_url)
                     elif password_action == 'change_password':
-                        if request.user.is_authenticated():
+                        if request.user.is_authenticated:
                             new_password = \
                                 login_form.cleaned_data['new_password']
                             request.user.set_password(new_password)
@@ -666,6 +666,7 @@ def signin(request, template_name='authopenid/signin.html'):
                     sreg_req = sreg.SRegRequest(required=['nickname', 'email'])
                 else:
                     sreg_req = sreg.SRegRequest(optional=['nickname', 'email'])
+
                 redirect_to = "%s%s?next=%s" % (get_url_host(request),
                                                 reverse('user_complete_openid_signin'),
                                                 encode_jwt({'next_url': next_url}))
@@ -698,7 +699,7 @@ def signin(request, template_name='authopenid/signin.html'):
                     return HttpResponseRedirect(oauth_url)
 
                 except util.OAuthError as e:
-                    logging.critical(unicode(e))
+                    logging.critical(str(e))
                     msg = _('Unfortunately, there was some problem when '
                             'connecting to %(provider)s, please try again '
                             'or use another provider'
@@ -714,7 +715,7 @@ def signin(request, template_name='authopenid/signin.html'):
                     request.session['next_url'] = next_url
                     return HttpResponseRedirect(redirect_url)
                 except util.OAuthError as e:
-                    logging.critical(unicode(e))
+                    logging.critical(str(e))
                     msg = _('Unfortunately, there was some problem when '
                             'connecting to %(provider)s, please try again '
                             'or use another provider'
@@ -744,7 +745,7 @@ def signin(request, template_name='authopenid/signin.html'):
                                     redirect_url=next_url
                                 )
                 except WpFault as e:
-                    logging.critical(unicode(e))
+                    logging.critical(str(e))
                     msg = _('The login password combination was not correct')
                     request.user.message_set.create(message = msg)
             else:
@@ -754,7 +755,7 @@ def signin(request, template_name='authopenid/signin.html'):
             logging.debug('login form is not valid')
             logging.debug(login_form.errors)
 
-    if request.method == 'GET' and request.user.is_authenticated():
+    if request.method == 'GET' and request.user.is_authenticated:
         view_subtype = 'change_openid'
     else:
         view_subtype = 'default'
@@ -823,7 +824,7 @@ def show_signin_view(
     else:
         answer = None
 
-    if request.user.is_authenticated():
+    if request.user.is_authenticated:
         existing_login_methods = UserAssociation.objects.filter(user = request.user)
         #annotate objects with extra data
         providers = util.get_enabled_login_providers()
@@ -872,7 +873,7 @@ def show_signin_view(
         'login_form': login_form,
         'use_password_login': util.use_password_login(),
         'account_recovery_form': account_recovery_form,
-        'openid_error_message':  request.REQUEST.get('msg',''),
+        'openid_error_message':  request.GET.get('msg',request.POST.get('msg','')),
         'account_recovery_message': account_recovery_message,
         'use_password_login': util.use_password_login(),
     }
@@ -881,21 +882,21 @@ def show_signin_view(
     minor_login_providers = util.get_enabled_minor_login_providers()
 
     #determine if we are only using password login
-    active_provider_names = [p['name'] for p in major_login_providers.values()]
-    active_provider_names.extend([p['name'] for p in minor_login_providers.values()])
+    active_provider_names = [p['name'] for p in list(major_login_providers.values())]
+    active_provider_names.extend([p['name'] for p in list(minor_login_providers.values())])
 
     have_buttons = True
     if (len(active_provider_names) == 1 and active_provider_names[0] == 'local'):
         have_buttons = False
         login_form.initial['login_provider_name'] = 'local'
-        if request.user.is_authenticated():
+        if request.user.is_authenticated:
             login_form.initial['password_action'] = 'change_password'
         else:
             login_form.initial['password_action'] = 'login'
 
     data['have_buttons'] = have_buttons
 
-    if request.user.is_authenticated():
+    if request.user.is_authenticated:
         data['existing_login_methods'] = existing_login_methods
         active_provider_names = [
                         item.provider_name for item in existing_login_methods
@@ -910,8 +911,8 @@ def show_signin_view(
                         active_provider_names = active_provider_names
                     )
 
-    data['major_login_providers'] = major_login_providers.values()
-    data['minor_login_providers'] = minor_login_providers.values()
+    data['major_login_providers'] = list(major_login_providers.values())
+    data['minor_login_providers'] = list(minor_login_providers.values())
 
     return render(request, template_name, data)
 
@@ -927,7 +928,7 @@ def change_password(request):
         data['message'] = _('Your new password is saved')
     else:
         data['errors'] = form.errors
-    return HttpResponse(simplejson.dumps(data), content_type='application/json')
+    return HttpResponse(json.dumps(data), content_type='application/json')
 
 @login_required
 def delete_login_method(request):
@@ -960,11 +961,11 @@ def complete_openid_signin(request):
     logging.debug('in askbot.deps.django_authopenid.complete')
     consumer = Consumer(request.session, util.DjangoOpenIDStore())
     # make sure params are encoded in utf8
-    params = dict((k,smart_unicode(v)) for k, v in request.GET.items())
+    params = dict((k, smart_text(v)) for k, v in list(request.GET.items()))
     return_to = get_url_host(request) + reverse('user_complete_openid_signin')
     openid_response = consumer.complete(params, return_to)
 
-    logging.debug(u'returned openid parameters were: %s' % unicode(params))
+    logging.debug('returned openid parameters were: %s' % str(params))
 
     if openid_response.status == SUCCESS:
         logging.debug('openid response status is SUCCESS')
@@ -1045,7 +1046,7 @@ def finalize_generic_signin(
         if redirect_url is None:
             redirect_url = reverse('questions')
 
-    if request.user.is_authenticated():
+    if request.user.is_authenticated:
         #this branch is for adding a new association
         if user is None:
             try:
@@ -1302,7 +1303,7 @@ def verify_email_and_register(request):
     for GET - give a field to paste the activation code
     and a button to send another validation email.
     """
-    presented_code = request.REQUEST.get('validation_code', None)
+    presented_code = request.GET.get('validation_code',request.POST.get('validation_code',None))
     if presented_code:
         try:
             #we get here with post if button is pushed
@@ -1343,7 +1344,7 @@ def verify_email_and_register(request):
 
             return HttpResponseRedirect(get_next_url(request))
         except Exception as error: #pylint: disable=broad-except
-            logging.critical('Could not verify account: %s', unicode(error).encode('utf-8'))
+            logging.critical('Could not verify account: %s', str(error).encode('utf-8'))
             message = _(
                 'Sorry, registration failed. '
                 'The token can be already used or has expired. Please try again'
@@ -1408,8 +1409,8 @@ def signup_with_password(request):
     context_data = {
         'form': form,
         'page_class': 'openid-signin',
-        'major_login_providers': major_login_providers.values(),
-        'minor_login_providers': minor_login_providers.values(),
+        'major_login_providers': list(major_login_providers.values()),
+        'minor_login_providers': list(minor_login_providers.values()),
         'login_form': login_form
     }
     return render(
@@ -1501,7 +1502,7 @@ def recover_account(request):
             return render(request, 'authopenid/verify_email.html', data)
         return show_signin_view(request, account_recovery_form=form)
 
-    key = request.REQUEST.get('validation_code', None)
+    key = get_request_params(request).get('validation_code', None)
     return auth_user_by_token(request, key)
 
 def auth_user_by_token(request, key):
@@ -1525,7 +1526,7 @@ def auth_user_by_token(request, key):
 
     user = authenticate(email_key=key, method='email_key')
     if user:
-        if request.user.is_authenticated() and user != request.user:
+        if request.user.is_authenticated and user != request.user:
             logout(request)
         login(request, user)
         from askbot.models import greet_new_user
