@@ -2,17 +2,17 @@
 This command is incomplete, current awards only
 Civic Duty badge
 """
-from __future__ import print_function
+
 
 from askbot.models import badges
 from askbot.models import User
 from askbot.models import Vote
 from askbot.utils.console import ProgressBar
-from django.core.management.base import NoArgsCommand
+from django.core.management import BaseCommand
 from django.utils import timezone
 
-class Command(NoArgsCommand):
-    def handle_noargs(self, *args, **kwargs):
+class Command(BaseCommand):
+    def handle(self, *args, **kwargs):
         now = timezone.now()
         awarded_count = 0
 
