@@ -15,19 +15,19 @@ from askbot.utils.functions import list_directory_files, zipzip
 class Command(BaseCommand):
     """Exports data for a user given his or her ID"""
 
-    option_list = BaseCommand.option_list + (
-        make_option('--user-id',
+    def add_arguments(self, parser):
+        parser.add_argument('--user-id',
                     action='store',
-                    type='int',
+                    type=int,
                     dest='user_id',
                     default=None,
-                    help='ID of the user whose data we will export'),
-        make_option('--file',
+                    help='ID of the user whose data we will export')
+        parser.add_argument('--file',
                     action='store',
                     dest='file_name',
-                    type='str',
+                    type=str,
                     default=None,
-                    help='Path to the output file, absolute or relative to CWD'))
+                    help='Path to the output file, absolute or relative to CWD')
 
     def handle(self, *args, **options): # pylint: disable=too-many-locals
         """Does the job of the command"""
@@ -56,13 +56,13 @@ class Command(BaseCommand):
         data = {'user_profile': user_profile}
 
         question_data = self.get_question_data(user)
-        data['questions'] = question_data.values()
+        data['questions'] = list(question_data.values())
 
         answer_data = self.get_post_data(user, 'answer')
-        data['answers'] = answer_data.values()
+        data['answers'] = list(answer_data.values())
 
         comment_data = self.get_post_data(user, 'comment')
-        data['comments'] = comment_data.values()
+        data['comments'] = list(comment_data.values())
 
         upfiles = self.get_upfiles(data)
 
@@ -199,7 +199,7 @@ class Command(BaseCommand):
         """Returns the same as the `get_post_data` method,
         but in addition fills in question title and the tags"""
         post_data = cls.get_post_data(user, 'question')
-        for question, datum in post_data.items():
+        for question, datum in list(post_data.items()):
             datum['title'] = question.thread.title
             datum['tags'] = question.thread.tagnames
 
