@@ -4,10 +4,10 @@ from askbot.models import User, UserProfile
 from askbot.utils.console import ProgressBar
 from avatar.conf import settings as avatar_settings
 from avatar.models import Avatar
-from django.core.management.base import NoArgsCommand
+from django.core.management import BaseCommand
 
-class Command(NoArgsCommand):
-    def handle_noargs(self, *args, **kwargs):
+class Command(BaseCommand):
+    def handle(self, *args, **kwargs):
 
         avatars = Avatar.objects.all()
         count = avatars.count()
