@@ -3,7 +3,7 @@ from django.core.exceptions import ImproperlyConfigured
 from django.core.management.base import BaseCommand, CommandError
 from django.core.serializers.xml_serializer import Serializer
 from django.db import connections, router, DEFAULT_DB_ALIAS
-from StringIO import StringIO
+from io import StringIO
 
 class XMLExportSerializer(Serializer):
     def serialize(self, queryset, **options):
@@ -16,7 +16,7 @@ class XMLExportSerializer(Serializer):
 
         self.stream = options.pop("stream", StringIO())
         self.selected_fields = options.pop("fields", None)
-        self.use_natural_keys = options.pop("use_natural_keys", False)
+        self.use_natural_foreign_keys = options.pop("use_natural_foreign_keys", False)
 
         self.start_serialization()
         for obj in queryset:
@@ -24,7 +24,7 @@ class XMLExportSerializer(Serializer):
             #the line below is the only one that was changed
             for field in obj._meta.fields:
                 if field.serialize:
-                    if field.rel is None:
+                    if field.remote_field is None:
                         if self.selected_fields is None or field.attname in self.selected_fields:
                             self.handle_field(obj, field)
                     else:
@@ -53,21 +53,20 @@ class Command(BaseCommand):
                 'fixtures into. Defaults to the "default" database.')
         parser.add_argument('-e', '--exclude', dest='exclude',action='append', default=['sessions', 'contenttypes'],
             help='An appname or appname.ModelName to exclude (use multiple --exclude to exclude multiple apps/models).')
-        parser.add_argument('-n', '--natural', action='store_true', dest='use_natural_keys', default=False,
+        parser.add_argument('--natural-foreign', action='store_true', dest='use_natural_foreign_keys', default=False,
             help='Use natural keys if they are available.')
         parser.add_argument('-a', '--all', action='store_true', dest='use_base_manager', default=False,
             help="Use Django's base manager to dump all models stored in the database, including those that would otherwise be filtered or modified by a custom manager.")
 
     def handle(self, *app_labels, **options):
         from django.apps import apps
-        from django.db.models import get_app, get_apps
 
         indent = options.get('indent', None)
         using = options.get('database', DEFAULT_DB_ALIAS)
         connection = connections[using]
         excludes = options.get('exclude',[])
         show_traceback = options.get('traceback', False)
-        use_natural_keys = options.get('use_natural_keys', False)
+        use_natural_foreign_keys = options.get('use_natural_foreign_keys', False)
         use_base_manager = options.get('use_base_manager', False)
 
         excluded_apps = set()
@@ -81,29 +80,29 @@ class Command(BaseCommand):
                 excluded_models.add(model_obj)
             else:
                 try:
-                    app_obj = get_app(exclude)
+                    app_obj = apps.get_app(exclude)
                     excluded_apps.add(app_obj)
                 except ImproperlyConfigured:
                     raise CommandError('Unknown app in excludes: %s' % exclude)
 
         if len(app_labels) == 0:
-            app_list = OrderedDict((app, None) for app in get_apps() if app not in excluded_apps)
+            app_list = OrderedDict((app, None) for app in apps.get_apps() if app not in excluded_apps)
         else:
             app_list = OrderedDict()
             for label in app_labels:
                 try:
                     app_label, model_label = label.split('.')
                     try:
-                        app = get_app(app_label)
+                        app = apps.get_app(app_label)
                     except ImproperlyConfigured:
                         raise CommandError("Unknown application: %s" % app_label)
                     if app in excluded_apps:
                         continue
-                    model = get_model(app_label, model_label)
+                    model = apps.get_model(app_label, model_label)
                     if model is None:
                         raise CommandError("Unknown model: %s.%s" % (app_label, model_label))
 
-                    if app in app_list.keys():
+                    if app in list(app_list.keys()):
                         if app_list[app] and model not in app_list[app]:
                             app_list[app].append(model)
                     else:
@@ -112,7 +111,7 @@ class Command(BaseCommand):
                     # This is just an app - no model qualifier
                     app_label = label
                     try:
-                        app = get_app(app_label)
+                        app = apps.get_app(app_label)
                     except ImproperlyConfigured:
                         raise CommandError("Unknown application: %s" % app_label)
                     if app in excluded_apps:
@@ -121,10 +120,10 @@ class Command(BaseCommand):
 
         # Now collate the objects to be serialized.
         objects = []
-        for model in sort_dependencies(app_list.items()):
+        for model in sort_dependencies(list(app_list.items())):
             if model in excluded_models:
                 continue
-            if not model._meta.proxy and router.allow_syncdb(using, model):
+            if not model._meta.proxy and router.allow_migrate(using, model):
                 if use_base_manager:
                     objects.extend(model._base_manager.using(using).all())
                 else:
@@ -132,7 +131,7 @@ class Command(BaseCommand):
 
         try:
             serializer = XMLExportSerializer()
-            return serializer.serialize(objects, indent=indent, use_natural_keys=use_natural_keys)
+            return serializer.serialize(objects, indent=indent, use_natural_foreign_keys=use_natural_foreign_keys)
         except Exception as e:
             if show_traceback:
                 raise
@@ -146,7 +145,6 @@ def sort_dependencies(app_list):
     dependency has it's dependencies serialized first.
     """
     from django.apps import apps
-
     # Process the list of models, and get the list of dependencies
     model_dependencies = []
     models = set()
@@ -167,12 +165,12 @@ def sort_dependencies(app_list):
             # Now add a dependency for any FK or M2M relation with
             # a model that defines a natural key
             for field in model._meta.fields:
-                if hasattr(field.rel, 'to'):
-                    rel_model = field.rel.to
+                if hasattr(field.remote_field, 'to'):
+                    rel_model = field.remote_field.to
                     if hasattr(rel_model, 'natural_key'):
                         deps.append(rel_model)
             for field in model._meta.many_to_many:
-                rel_model = field.rel.to
+                rel_model = field.remote_field.to
                 if hasattr(rel_model, 'natural_key'):
                     deps.append(rel_model)
             model_dependencies.append((model, deps))
