@@ -1,4 +1,4 @@
-from django.core.management.base import NoArgsCommand
+from django.core.management import BaseCommand
 from askbot.models import UserProfile
 
 
@@ -9,8 +9,8 @@ def rebuild_profile_caches(profiles):
         profile.update_cache()
 
 
-class Command(NoArgsCommand):
-    def handle_noargs(self, *args, **kwargs):
+class Command(BaseCommand):
+    def handle(self, *args, **kwargs):
         # Make sure all superusers have their status set to 'd'
         profiles = (UserProfile.objects
                  .filter(pk__is_superuser=True)
