@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals
+
 
 from django.db import models, migrations
 from django.conf import settings
@@ -15,7 +15,7 @@ class Migration(migrations.Migration):
         migrations.AlterField(
             model_name='vote',
             name='user',
-            field=models.ForeignKey(related_name='askbot_votes', to=settings.AUTH_USER_MODEL),
+            field=models.ForeignKey(related_name='askbot_votes', to=settings.AUTH_USER_MODEL, on_delete=models.CASCADE),
             preserve_default=True,
         ),
     ]
