@@ -13,7 +13,7 @@ class Message(models.Model):
     actions. For example, "The poll Foo was created successfully." is a
     message.
     """
-    user = models.ForeignKey(User, related_name='_message_set')
+    user = models.ForeignKey(User, related_name='_message_set', on_delete=models.CASCADE)
     message = models.TextField(ugettext_lazy('message'))
 
     class Meta:
@@ -22,8 +22,5 @@ class Message(models.Model):
         app_label = 'askbot'
         db_table = 'askbot_message'
 
-    def __unicode__(self):
-        return self.message
-
     def __str__(self):
-        return self.message.encode('utf-8')
+        return self.message
