@@ -10,11 +10,10 @@ from django.db.models import F, Q
 from django.contrib.auth.models import User
 from django.core import cache  # import cache, not from cache import cache, to be able to monkey-patch cache.cache in test cases
 from django.core import exceptions as django_exceptions
-from django.core.urlresolvers import reverse
 from django.template.loader import get_template
 from django.template import Context
 from django.utils.translation import ugettext as _
-from django.utils.translation import ungettext, string_concat, get_language
+from django.utils.translation import get_language
 from django.utils import timezone
 
 import askbot
@@ -74,7 +73,7 @@ def default_title_renderer(thread):
     else:
         attr = None
     if attr is not None:
-        return u'%s %s' % (thread.title, unicode(attr))
+        return '%s %s' % (thread.title, str(attr))
     else:
         return thread.title
 
@@ -83,7 +82,7 @@ class ThreadQuerySet(models.query.QuerySet):
 
     def get_visible(self, user):
         """filters out threads not belonging to the user groups"""
-        if user.is_authenticated():
+        if user.is_authenticated:
             groups = user.get_groups()
         else:
             groups = [Group.objects.get_global_group()]
@@ -144,7 +143,7 @@ class ThreadManager(BaseQuerySetManager):
                     tag_counts[tag_name] += 1
                 else:
                     tag_counts[tag_name] = 1
-        tag_list = tag_counts.keys()
+        tag_list = list(tag_counts.keys())
         tag_list.sort(key=lambda t: tag_counts[t], reverse=True)
 
         # note that double quote placement is important here
@@ -158,7 +157,7 @@ class ThreadManager(BaseQuerySetManager):
             tag_list = tag_list[:5]
             last_topic = _('" and more')
 
-        return '"' + '", "'.join(tag_list) + unicode(last_topic)
+        return '"' + '", "'.join(tag_list) + str(last_topic)
 
     def create(self, *args, **kwargs):
         raise NotImplementedError
@@ -199,7 +198,7 @@ class ThreadManager(BaseQuerySetManager):
             author=author,
             is_anonymous=is_anonymous,
             text=text,
-            comment=unicode(const.POST_STATUS['default_version']),
+            comment=str(const.POST_STATUS['default_version']),
             revised_at=added_at,
             by_email=by_email,
             email_address=email_address,
@@ -287,17 +286,17 @@ class ThreadManager(BaseQuerySetManager):
         if lang_mode == 'url-lang':
             primary_filter['language_code'] = get_language()
         elif lang_mode == 'user-lang':
-            if request_user.is_authenticated():
+            if request_user.is_authenticated:
                 language_codes = request_user.get_languages()
             else:
-                language_codes = dict(django_settings.LANGUAGES).keys()
+                language_codes = list(dict(django_settings.LANGUAGES).keys())
             primary_filter['language_code__in'] = language_codes
 
         # TODO: add a possibility to see deleted questions
         qs = self.filter(**primary_filter)
 
         if askbot_settings.CONTENT_MODERATION_MODE == 'premoderation':
-            if request_user.is_authenticated():
+            if request_user.is_authenticated:
                 qs = qs.filter(Q(approved=True) | Q(posts__author_id=request_user.pk))
             else:
                 qs = qs.filter(approved=True)
@@ -412,7 +411,7 @@ class ThreadManager(BaseQuerySetManager):
                 meta_data['author_name'] = u.username
 
         # get users tag filters
-        if request_user and request_user.is_authenticated():
+        if request_user and request_user.is_authenticated:
             # mark questions tagged with interesting tags
             # a kind of fancy annotation, would be nice to avoid it
             lang = get_language()
@@ -573,8 +572,8 @@ class ThreadToGroup(models.Model):
         (SHOW_PUBLISHED_RESPONSES, 'show only published responses'),
         (SHOW_ALL_RESPONSES, 'show all responses')
     )
-    thread = models.ForeignKey('Thread')
-    group = models.ForeignKey(Group)
+    thread = models.ForeignKey('Thread', on_delete=models.CASCADE)
+    group = models.ForeignKey(Group, on_delete=models.CASCADE)
     visibility = models.SmallIntegerField(choices=VISIBILITY_CHOICES,
                                           default=SHOW_ALL_RESPONSES)
 
@@ -599,7 +598,7 @@ class Thread(models.Model):
     favourite_count = models.PositiveIntegerField(default=0)
     answer_count = models.PositiveIntegerField(default=0)
     last_activity_at = models.DateTimeField(default=timezone.now)
-    last_activity_by = models.ForeignKey(User, related_name='unused_last_active_in_threads')
+    last_activity_by = models.ForeignKey(User, related_name='unused_last_active_in_threads', on_delete=models.CASCADE)
     language_code = LanguageCodeField()
 
     # TODO: these two are redundant (we used to have a "star" and "subscribe"
@@ -609,7 +608,7 @@ class Thread(models.Model):
                                           related_name='unused_favorite_threads')
 
     closed = models.BooleanField(default=False)
-    closed_by = models.ForeignKey(User, null=True, blank=True)  # , related_name='closed_questions')
+    closed_by = models.ForeignKey(User, null=True, blank=True, on_delete=models.CASCADE)  # , related_name='closed_questions')
     closed_at = models.DateTimeField(null=True, blank=True)
     close_reason = models.SmallIntegerField(choices=const.CLOSE_REASONS,
                                             null=True,
@@ -621,7 +620,7 @@ class Thread(models.Model):
     # approvals - by whom and when
     approved = models.BooleanField(default=True, db_index=True)
 
-    accepted_answer = models.ForeignKey('Post', null=True, blank=True, related_name='+')
+    accepted_answer = models.ForeignKey('Post', null=True, blank=True, related_name='+', on_delete=models.CASCADE)
     added_at = models.DateTimeField(auto_now_add=True)
 
     # db_column will be removed later
@@ -676,26 +675,26 @@ class Thread(models.Model):
         for hint in hints:
             orig_hints[hint.lower()] = hint
 
-        norm_hints = orig_hints.keys()
-        norm_tags = map(lambda v: v.lower(), existing_tags)
+        norm_hints = list(orig_hints.keys())
+        norm_tags = [v.lower() for v in existing_tags]
 
         common_words = (set(norm_hints) & post_words) - set(norm_tags)
 
         # 4) for each common word count occurances in corpus
         counts = dict()
         for word in common_words:
-            counts[word] = sum(map(lambda w: w.lower() == word.lower(), post_words))
+            counts[word] = sum([w.lower() == word.lower() for w in post_words])
 
         # 5) sort words by count
         sorted_words = sorted(
                         common_words,
-                        lambda a, b: cmp(counts[b], counts[a])
-                    )
+                        key=lambda a: counts[a],
+                        reverse=True)
 
         # 6) extract correct number of most frequently used tags
         need_tags = askbot_settings.MAX_TAGS_PER_POST - len(existing_tags)
         add_tags = sorted_words[0:need_tags]
-        add_tags = map(lambda h: orig_hints[h], add_tags)
+        add_tags = [orig_hints[h] for h in add_tags]
 
         tagnames = ' '.join(existing_tags + add_tags)
 
@@ -744,7 +743,7 @@ class Thread(models.Model):
             'deleted': False
         }
 
-        if user and user.is_authenticated() and askbot_settings.GROUPS_ENABLED:
+        if user and user.is_authenticated and askbot_settings.GROUPS_ENABLED:
             # get post with groups shared with having at least
             # one of the user groups
             # of those posts return the latest revision
@@ -949,7 +948,7 @@ class Thread(models.Model):
         if self.tagnames.strip() == '':
             return list()
         else:
-            return self.tagnames.split(u' ')
+            return self.tagnames.split(' ')
 
     def get_title(self):
         title_renderer = load_plugin(
@@ -968,7 +967,7 @@ class Thread(models.Model):
 
     def has_moderator(self, user):
         """true if ``user`` is also a thread moderator"""
-        if user.is_anonymous():
+        if user.is_anonymous:
             return False
         if user.is_administrator_or_moderator():
             if askbot_settings.GROUPS_ENABLED:
@@ -990,7 +989,7 @@ class Thread(models.Model):
         return False
 
     def tagname_meta_generator(self):
-        return u','.join([unicode(tag) for tag in self.get_tag_names()])
+        return ','.join([str(tag) for tag in self.get_tag_names()])
 
     def all_answers(self):
         return self.posts.get_answers()
@@ -999,7 +998,7 @@ class Thread(models.Model):
         """returns query set for answers to this question
         that may be shown to the given user
         """
-        if user is None or user.is_anonymous():
+        if user is None or user.is_anonymous:
             return self.posts.get_answers().filter(deleted=False)
         else:
             return self.posts.get_answers(
@@ -1026,7 +1025,7 @@ class Thread(models.Model):
     def invalidate_cached_summary_html(self):
         """Invalidates cached summary html in all activated languages"""
         langs = translation_utils.get_language_codes()
-        keys = map(lambda v: self.get_summary_cache_key(v), langs)
+        keys = [self.get_summary_cache_key(v) for v in langs]
         cache.cache.delete_many(keys)
 
     def get_summary_cache_key(self, lang=None):
@@ -1041,8 +1040,8 @@ class Thread(models.Model):
         changes in the post data - on votes, adding,
         deleting, editing content"""
         # we can call delete_many() here if using Django > 1.2
-        sort_methods = map(lambda v: v[0], const.ANSWER_SORT_METHODS)
-        keys = map(lambda v: self.get_post_data_cache_key(v), sort_methods)
+        sort_methods = [v[0] for v in const.ANSWER_SORT_METHODS]
+        keys = [self.get_post_data_cache_key(v) for v in sort_methods]
         cache.cache.delete_many(keys)
 
     def reset_cached_data(self):
@@ -1060,7 +1059,7 @@ class Thread(models.Model):
             question = post_data[0]
             answers = post_data[1]
             question.reverse_cached_comments()
-            map(lambda v: v.reverse_cached_comments(), answers)
+            list(map(lambda v: v.reverse_cached_comments(), answers))
             return post_data
 
         def find_posts(posts, need_ids):
@@ -1084,14 +1083,8 @@ class Thread(models.Model):
                 return 1
             return 2
 
-        def cmp_post_types(a, b):
-            """need to sort by post type"""
-            at = post_type_ord(a)
-            bt = post_type_ord(b)
-            return cmp(at, bt)
-
         post_data = self.get_cached_post_data(user=user, sort_method=sort_method)
-        if user.is_anonymous():
+        if user.is_anonymous:
             if askbot_settings.COMMENTS_REVERSED:
                 reverse_comments(post_data)
             return post_data
@@ -1121,9 +1114,9 @@ class Thread(models.Model):
                     all_posts.append(question)
                 posts = find_posts(all_posts, post_id_set)
 
-                rev_map = dict(zip(suggested_post_ids, suggested_revs))
+                rev_map = dict(list(zip(suggested_post_ids, suggested_revs)))
 
-                for post_id, post in posts.items():
+                for post_id, post in list(posts.items()):
                     rev = rev_map[post_id]
                     # patching work
                     post.text = rev.text
@@ -1139,7 +1132,7 @@ class Thread(models.Model):
                     from askbot.models import Post
                     # order by insures that
                     posts = list(Post.objects.filter(id__in=post_id_set))
-                    for post in sorted(posts, cmp=cmp_post_types):
+                    for post in sorted(posts, key=post_type_ord):
                         rev = rev_map[post.id]
                         post.text = rev.text
                         post.html = post.parse_post_text()['html']
@@ -1147,7 +1140,7 @@ class Thread(models.Model):
                         post_to_author[post.id] = rev.author_id
                         if post.is_comment():
                             parents = find_posts(all_posts, set([post.parent_id]))
-                            parent = parents.values()[0]
+                            parent = list(parents.values())[0]
                             parent.add_cached_comment(post)
                         if post.is_answer():
                             answers.insert(0, post)
@@ -1196,7 +1189,7 @@ class Thread(models.Model):
 
         thread_posts = self.posts.all()
         if askbot_settings.GROUPS_ENABLED:
-            if user is None or user.is_anonymous():
+            if user is None or user.is_anonymous:
                 groups = (Group.objects.get_global_group(),)
             else:
                 groups = user.get_groups()
@@ -1255,11 +1248,11 @@ class Thread(models.Model):
                 question_post = post
 
         # 2) sort comments in the temporal order
-        for comment_list in comment_map.values():
+        for comment_list in list(comment_map.values()):
             comment_list.sort(key=operator.attrgetter('added_at'))
 
         # 3) attach comments to question and the answers
-        for post_id, comment_list in comment_map.items():
+        for post_id, comment_list in list(comment_map.items()):
             try:
                 post_map[post_id].set_cached_comments(comment_list)
             except KeyError:
@@ -1396,7 +1389,7 @@ class Thread(models.Model):
 
     def is_followed_by(self, user=None):
         """True if thread is followed by user"""
-        if user and user.is_authenticated():
+        if user and user.is_authenticated:
             return self.followed_by.filter(id=user.id).count() > 0
         return False
 
@@ -1655,12 +1648,12 @@ class Thread(models.Model):
             author=retagged_by,
             revised_at=retagged_at,
             tagnames=tagnames,
-            summary=unicode(const.POST_STATUS['retagged']),
+            summary=str(const.POST_STATUS['retagged']),
             text=latest_revision.text
         )
 
     def has_favorite_by_user(self, user):
-        if not user.is_authenticated():
+        if not user.is_authenticated:
             return False
 
         return FavoriteQuestion.objects.filter(thread=self, user=user).exists()
@@ -1740,12 +1733,12 @@ class Thread(models.Model):
         return html
 
     def summary_html_cached(self):
-        return cache.cache.has_key(self.get_summary_cache_key())
+        return self.get_summary_cache_key() in cache.cache
 
 
 class QuestionView(models.Model):
-    question = models.ForeignKey('Post', related_name='viewed')
-    who = models.ForeignKey(User, related_name='question_views')
+    question = models.ForeignKey('Post', related_name='viewed', on_delete=models.CASCADE)
+    who = models.ForeignKey(User, related_name='question_views', on_delete=models.CASCADE)
     when = models.DateTimeField()
 
     class Meta:
@@ -1754,28 +1747,25 @@ class QuestionView(models.Model):
 
 class FavoriteQuestion(models.Model):
     """A favorite Question of a User."""
-    thread = models.ForeignKey(Thread)
-    user = models.ForeignKey(User, related_name='user_favorite_questions')
+    thread = models.ForeignKey(Thread, on_delete=models.CASCADE)
+    user = models.ForeignKey(User, related_name='user_favorite_questions', on_delete=models.CASCADE)
     added_at = models.DateTimeField(default=timezone.now)
 
     class Meta:
         app_label = 'askbot'
-        db_table = u'favorite_question'
+        db_table = 'favorite_question'
         verbose_name = _("favorite question")
         verbose_name_plural = _("favorite questions")
 
     def __str__(self):
-        return unicode(self).encode('utf-8')
-
-    def __unicode__(self):
-        return u'[%s] favorited at %s' % (self.user, self.added_at)
+        return '[%s] favorited at %s' % (self.user, self.added_at)
 
 
 class DraftQuestion(DraftContent):
     """Provides space to solve unpublished draft
     questions. Contents is used to populate the Ask form.
     """
-    author = models.ForeignKey(User)
+    author = models.ForeignKey(User, on_delete=models.CASCADE)
     title = models.CharField(max_length=300, null=True)
     tagnames = models.CharField(max_length=125, null=True)
 
