@@ -3,9 +3,9 @@ import logging
 import re
 from django.db import models
 from django.db.models import Q
-from django.db.backends.dummy.base import IntegrityError
+from django.db.utils import IntegrityError
 from django.contrib.contenttypes.models import ContentType
-from django.contrib.contenttypes import generic
+from django.contrib.contenttypes import fields
 from django.contrib.auth.models import User
 from django.contrib.auth.models import Group as AuthGroup
 from django.core import exceptions
@@ -99,7 +99,7 @@ class MockUser(object):
 
     def get_avatar_url(self, size):
         return ''
-    
+
     def get_full_name(self):
         return ''
 
@@ -143,7 +143,7 @@ class ActivityQuerySet(models.query.QuerySet):
             else:
                 logging.debug(
                             'method get_origin_post() not implemented for %s' \
-                            % unicode(post)
+                            % str(post)
                         )
         return list(origin_posts)
 
@@ -160,7 +160,7 @@ class ActivityQuerySet(models.query.QuerySet):
 
         #3) get links from activity objects to content objects
         objects_by_activity = dict()
-        for content_type_id, object_id_list in content_object_ids.items():
+        for content_type_id, object_id_list in list(content_object_ids.items()):
             content_type = ContentType.objects.get_for_id(content_type_id)
             model_class = content_type.model_class()
             content_objects = model_class.objects.filter(id__in=object_id_list)
@@ -279,8 +279,8 @@ class ActivityAuditStatus(models.Model):
         (STATUS_NEW, 'new'),
         (STATUS_SEEN, 'seen')
     )
-    user = models.ForeignKey(User)
-    activity = models.ForeignKey('Activity')
+    user = models.ForeignKey(User, on_delete=models.CASCADE)
+    activity = models.ForeignKey('Activity', on_delete=models.CASCADE)
     status = models.SmallIntegerField(choices=STATUS_CHOICES, default=STATUS_NEW)
 
     class Meta:
@@ -296,16 +296,16 @@ class Activity(models.Model):
     """
     We keep some history data for user activities
     """
-    user = models.ForeignKey(User)
+    user = models.ForeignKey(User, on_delete=models.CASCADE)
     recipients = models.ManyToManyField(User, through=ActivityAuditStatus, related_name='incoming_activity')
     activity_type = models.SmallIntegerField(choices=const.TYPE_ACTIVITY, db_index=True)
     active_at = models.DateTimeField(default=timezone.now)
-    content_type = models.ForeignKey(ContentType)
+    content_type = models.ForeignKey(ContentType, on_delete=models.CASCADE)
     object_id = models.PositiveIntegerField(db_index=True)
-    content_object = generic.GenericForeignKey('content_type', 'object_id')
+    content_object = fields.GenericForeignKey('content_type', 'object_id')
 
     #todo: remove this denorm question field when Post model is set up
-    question = models.ForeignKey('Post', null=True)
+    question = models.ForeignKey('Post', null=True, on_delete=models.CASCADE)
 
     is_auditted = models.BooleanField(default=False)
     #add summary field.
@@ -313,12 +313,12 @@ class Activity(models.Model):
 
     objects = ActivityManager()
 
-    def __unicode__(self):
-        return u'[%s] was active at %s' % (self.user.username, self.active_at)
+    def __str__(self):
+        return '[%s] was active at %s' % (self.user.username, self.active_at)
 
     class Meta:
         app_label = 'askbot'
-        db_table = u'activity'
+        db_table = 'activity'
         verbose_name = _("activity")
         verbose_name_plural = _("activities")
 
@@ -420,7 +420,7 @@ class EmailFeedSetting(models.Model):
         ('n', ugettext_lazy('No email')),
     )
 
-    subscriber = models.ForeignKey(User, related_name='notification_subscriptions')
+    subscriber = models.ForeignKey(User, related_name='notification_subscriptions', on_delete=models.CASCADE)
     feed_type = models.CharField(max_length=16, choices=FEED_TYPE_CHOICES)
     frequency = models.CharField(
                     max_length=8,
@@ -438,14 +438,11 @@ class EmailFeedSetting(models.Model):
         app_label = 'askbot'
 
     def __str__(self):
-        return unicode(self).encode('utf-8')
-
-    def __unicode__(self):
         if self.reported_at is None:
             reported_at = "'not yet'"
         else:
             reported_at = '%s' % self.reported_at.strftime('%d/%m/%y %H:%M')
-        return u'Email feed for %s type=%s, frequency=%s, reported_at=%s' % (
+        return 'Email feed for %s type=%s, frequency=%s, reported_at=%s' % (
                                                      self.subscriber,
                                                      self.feed_type,
                                                      self.frequency,
@@ -489,8 +486,8 @@ class GroupMembership(models.Model):
     )
     ALL_LEVEL_CHOICES = LEVEL_CHOICES + ((NONE, 'none'),)
 
-    group = models.ForeignKey(AuthGroup, related_name='user_membership')
-    user = models.ForeignKey(User, related_name='group_membership')
+    group = models.ForeignKey(AuthGroup, related_name='user_membership', on_delete=models.CASCADE)
+    user = models.ForeignKey(User, related_name='group_membership', on_delete=models.CASCADE)
     level = models.SmallIntegerField(
         default=FULL, choices=LEVEL_CHOICES,)
 
@@ -592,7 +589,7 @@ class Group(AuthGroup):
     logo_url = models.URLField(null=True)
     description = models.OneToOneField(
                     'Post', related_name='described_group',
-                    null=True, blank=True
+                    null=True, blank=True, on_delete=models.CASCADE
                 )
     moderate_email = models.BooleanField(default=True)
     moderate_answers_to_enquirers = models.BooleanField(
@@ -647,7 +644,7 @@ class Group(AuthGroup):
         templates. The value must match the verbose versions of the
         openness choices!!!
         """
-        if user.is_anonymous():
+        if user.is_anonymous:
             return 'closed'
 
         # A special case - automatic global group cannot be joined or left
@@ -686,7 +683,7 @@ class Group(AuthGroup):
         emails = functions.split_list(self.preapproved_emails)
         email_field = EmailField()
         try:
-            map(lambda v: email_field.clean(v), emails)
+            list(map(lambda v: email_field.clean(v), emails))
         except exceptions.ValidationError:
             raise exceptions.ValidationError(
                 _('Please give a list of valid email addresses.')
@@ -697,7 +694,7 @@ class Group(AuthGroup):
         from askbot.forms import DomainNameField
         domain_field = DomainNameField()
         try:
-            map(lambda v: domain_field.clean(v), domains)
+            list(map(lambda v: domain_field.clean(v), domains))
         except exceptions.ValidationError:
             raise exceptions.ValidationError(
                 _('Please give a list of valid email domain names.')
