@@ -7,7 +7,7 @@ question: why not run these from askbot/__init__.py?
 
 the main function is run_startup_tests
 """
-from __future__ import print_function
+
 from askbot.conf.static_settings import settings as django_settings
 import askbot
 import django
@@ -15,8 +15,8 @@ import os
 import pkg_resources
 import re
 import sys
-import urllib
-from urlparse import urlparse
+import urllib.request, urllib.parse, urllib.error
+from urllib.parse import urlparse
 from django.db import connection
 from django.core.cache import cache
 from django.core.exceptions import ImproperlyConfigured
@@ -61,7 +61,7 @@ def domain_is_bad():
 
 def askbot_warning(line):
     """prints a warning with the nice header, but does not quit"""
-    print(unicode(line).encode('utf-8'), file=sys.stderr)
+    print(str(line).encode('utf-8'), file=sys.stderr)
 
 
 def print_errors(error_messages, header=None, footer=None):
@@ -166,9 +166,8 @@ def test_middleware():
     required_middleware.extend([
         'askbot.middleware.view_log.ViewLogMiddleware',
         'askbot.middleware.spaceless.SpacelessMiddleware',
-        'askbot.middleware.csrf.CsrfViewMiddleware'
     ])
-    found_middleware = [x for x in django_settings.MIDDLEWARE_CLASSES
+    found_middleware = [x for x in django_settings.MIDDLEWARE
                         if x in required_middleware]
     if found_middleware != required_middleware:
         # either middleware is out of order or it's missing an item
@@ -176,7 +175,7 @@ def test_middleware():
         middleware_text = ''
         if missing_middleware_set:
             error_message = """\n\nPlease add the following middleware (listed after this message)
-to the MIDDLEWARE_CLASSES variable in your site settings.py file.
+to the MIDDLEWARE variable in your site settings.py file.
 The order the middleware records is important, please take a look at the example in
 https://github.com/ASKBOT/askbot-devel/blob/master/askbot/setup_templates/settings.py:\n\n"""
             middleware_text = format_as_text_tuple_entries(missing_middleware_set)
@@ -195,10 +194,10 @@ for the correct order.\n\n"""
     ]
 
     invalid_middleware = [x for x in canceled_middleware
-                          if x in django_settings.MIDDLEWARE_CLASSES]
+                          if x in django_settings.MIDDLEWARE]
     if invalid_middleware:
         error_message = """\n\nPlease remove the following middleware entries from
-the list of MIDDLEWARE_CLASSES in your settings.py - these are not used any more:\n\n"""
+the list of MIDDLEWARE in your settings.py - these are not used any more:\n\n"""
         middleware_text = format_as_text_tuple_entries(invalid_middleware)
         raise AskbotConfigError(error_message + middleware_text)
 
@@ -209,7 +208,7 @@ def try_import(module_name, pypi_package_name, show_requirements_message=True,
     try:
         load_module(module_name)
     except ImportError as error:
-        message = 'Error: ' + unicode(error)
+        message = 'Error: ' + str(error)
         message += '\n\nPlease run: >pip install %s' % pypi_package_name
         if show_requirements_message:
             message += '\n\nTo install all the dependencies at once, type:'
@@ -229,6 +228,19 @@ def unparse_requirement(req):
         line += ' [%s]' % ','.join(req.extras)
     return line
 
+def assert_version_matches(mod_ver, op, spec_ver):
+    """Asserts that version strings match the op"""
+    if op == '==':
+        assert mod_ver == spec_ver
+    elif op == '>':
+        assert mod_ver > spec_ver
+    elif op == '<':
+        assert mod_ver < spec_ver
+    elif op == '<=':
+        assert mod_ver <= spec_ver
+    elif op == '>=':
+        assert mod_ver >= spec_ver
+
 
 def test_specs(req):
     """Check if the dependency described by `req` value
@@ -256,23 +268,21 @@ def test_specs(req):
         for spec in req.specs:
             op = spec[0]
             spec_ver = map_int(spec[1].split('.'))
-            if op == '==':
-                assert mod_ver == spec_ver
-            elif op == '>':
-                assert mod_ver > spec_ver
-            elif op == '<':
-                assert mod_ver < spec_ver
-            elif op == '<=':
-                assert mod_ver <= spec_ver
-            elif op == '>=':
-                assert mod_ver >= spec_ver
-            else:
+            if op not in ('==', '>', '<', '<=', '>='):
                 raise ValueError('Unsupported pip dependency version operator %s' % op)
+
+            try:
+                assert_version_matches(mod_ver, op, spec_ver)
+            except TypeError:
+                mod_ver = [str(item) for item in mod_ver]
+                spec_ver = [str(item) for item in spec_ver]
+                assert_version_matches(mod_ver, op, spec_ver)
+
     except AssertionError:
         data = {
             'name': req.name,
             'need_spec': unparse_requirement(req),
-            'mod_ver': '.'.join(map(lambda v: str(v), mod_ver))
+            'mod_ver': '.'.join([str(v) for v in mod_ver])
         }
         message = """Unsupported version of module {name},
 found version {mod_ver}, {need_spec} required.
@@ -290,7 +300,7 @@ def get_req_name_from_spec(spec):
 def find_mod_name(req_name):
     from askbot import REQUIREMENTS
     req2mod = dict([(get_req_name_from_spec(v), k)
-                    for (k, v) in REQUIREMENTS.items()])
+                    for (k, v) in list(REQUIREMENTS.items())])
     return req2mod[req_name]
 
 
@@ -298,7 +308,7 @@ def test_modules():
     """tests presence of required modules"""
     from askbot import REQUIREMENTS
     # flatten requirements into file-like string
-    req_text = '\n'.join(REQUIREMENTS.values())
+    req_text = '\n'.join(list(REQUIREMENTS.values()))
     import requirements
     parsed_requirements = requirements.parse(req_text)
     for req in parsed_requirements:
@@ -430,7 +440,7 @@ class SettingsTester(object):
         * error_message
         """
         settings_module = os.environ['DJANGO_SETTINGS_MODULE']
-        self.settings = load_module(settings_module.encode('utf-8'))
+        self.settings = load_module(settings_module)
         self.messages = list()
         self.requirements = requirements
 
@@ -659,10 +669,10 @@ def test_settings_for_test_runner():
         errors.append(
             'When testing - remove debug_toolbar from INSTALLED_APPS')
     if 'debug_toolbar.middleware.DebugToolbarMiddleware' in \
-        django_settings.MIDDLEWARE_CLASSES:
+        django_settings.MIDDLEWARE:
         errors.append(
             'When testing - remove debug_toolbar.middleware.DebugToolbarMiddleware '
-            'from MIDDLEWARE_CLASSES')
+            'from MIDDLEWARE')
     print_errors(errors)
 
 
@@ -683,7 +693,7 @@ def test_haystack():
                 message += """HAYSTACK_CONNECTIONS = {
                     'default': {
                     'ENGINE': 'haystack.backends.simple_backend.SimpleEngine',
-                     
+
                     }"""
                 errors.append(message)
 
@@ -716,12 +726,12 @@ def test_custom_user_profile_tab():
         func_name = tab_settings.get('CONTEXT_GENERATOR', None)
 
         errors = list()
-        if (name is None) or (not(isinstance(name, basestring))):
+        if (name is None) or (not(isinstance(name, str))):
             errors.append("%s['NAME'] must be a string" % setting_name)
         if (slug is None) or (not(isinstance(slug, str))):
             errors.append("%s['SLUG'] must be an ASCII string" % setting_name)
 
-        if urllib.quote_plus(slug) != slug:
+        if urllib.parse.quote_plus(slug) != slug:
             errors.append(
                 "%s['SLUG'] must be url safe, make it simple" % setting_name)
 
@@ -848,11 +858,7 @@ def test_cache_backend():
             'the cache backend is working properly.')
     print_errors(errors)
 
-    # test the cache backend settings
-    if django.VERSION[1] > 2:
-        backend = django_settings.CACHES['default']['BACKEND']
-    else:
-        backend = django_settings.CACHE_BACKEND
+    backend = django_settings.CACHES['default']['BACKEND']
 
     if backend.strip() == '' or 'dummy' in backend:
         message = """Please enable at least a "locmem" cache (for a single process server).
@@ -921,10 +927,10 @@ def test_locale_middlewares():
     errors = list()
 
     if askbot.is_multilingual():
-        if askbot_locale_middleware in django_settings.MIDDLEWARE_CLASSES:
-            errors.append("Please remove '%s' from your MIDDLEWARE_CLASSES" % askbot_locale_middleware)
-        if django_locale_middleware not in django_settings.MIDDLEWARE_CLASSES:
-            errors.append("Please add '%s' to your MIDDLEWARE_CLASSES" % django_locale_middleware)
+        if askbot_locale_middleware in django_settings.MIDDLEWARE:
+            errors.append("Please remove '%s' from your MIDDLEWARE" % askbot_locale_middleware)
+        if django_locale_middleware not in django_settings.MIDDLEWARE:
+            errors.append("Please add '%s' to your MIDDLEWARE" % django_locale_middleware)
 
     print_errors(errors)
 
@@ -964,9 +970,9 @@ ASKBOT_LANGUAGE_MODE = 'single-lang' or just delete the setting""")
 
     if mode == 'url-lang':
         middleware = 'django.middleware.locale.LocaleMiddleware'
-        if middleware not in django_settings.MIDDLEWARE_CLASSES:
+        if middleware not in django_settings.MIDDLEWARE:
             errors.append(
-                "add 'django.middleware.locale.LocaleMiddleware' to your MIDDLEWARE_CLASSES "
+                "add 'django.middleware.locale.LocaleMiddleware' to your MIDDLEWARE "
                 "if you want a multilingual setup"
             )
 
@@ -999,21 +1005,13 @@ def test_versions():
     """inform of version incompatibilities, where possible"""
     errors = list()
     py_ver = sys.version_info
-    # python3 will not work
-    if py_ver[0] == 3:
-        errors.append(
-            'Askbot does not yet support Python3, please use '
-            'the latest release of Python 2.x')
 
     dj_ver = django.VERSION
     upgrade_msg = 'About upgrades, please read http://askbot.org/doc/upgrade.html'
-    if dj_ver < (1, 7) or dj_ver >= (1, 9):
-        errors.append('This version of Askbot supports only django 1.7 and 1.8 ' + upgrade_msg)
-    elif py_ver[:3] < (2, 7, 0):
-        errors.append(
-            'Django 1.7 and higher requires Python 2.7'
-            'please see the release notes.\n'
-            'https://docs.djangoproject.com/en/dev/releases/1.7/')
+    if dj_ver < (2, 2) or dj_ver >= (2, 3):
+        errors.append('This version of Askbot supports only django 2.2 ' + upgrade_msg)
+    elif py_ver[:3] < (3, 6, 0):
+        errors.append('Askbot requires Python 3.6')
 
     print_errors(errors)
 
