@@ -1,6 +1,6 @@
 import datetime
 from django.test.client import Client
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.conf import settings
 from django.test import TestCase
 from django.core import exceptions
@@ -97,7 +97,7 @@ class SeeOffensiveFlagsPermissionAssertionTests(utils.AskbotTestCase):
 
     def test_admin_can_see_flags(self):
         question = self.post_question()
-        self.other_user.set_admin_status()
+        self.other_user.set_status('d')
         self.other_user.save()
         assert(self.other_user.reputation < self.min_rep)
         self.assertTrue(
@@ -230,7 +230,7 @@ class DeleteAnswerPermissionAssertionTests(utils.AskbotTestCase):
 
     def test_low_rep_admin_can_delete(self):
         self.post_answer(user = self.other_user)
-        self.user.set_admin_status()
+        self.user.set_status('d')
         self.user.save()
         assert(self.user.reputation < self.min_rep)
         self.assert_can_delete()
@@ -341,7 +341,7 @@ class CloseQuestionPermissionAssertionTests(utils.AskbotTestCase):
         )
 
     def test_low_rep_admin_can_close(self):
-        self.other_user.set_admin_status()
+        self.other_user.set_status('d')
         self.other_user.save()
         assert(self.other_user.reputation < self.min_rep)
         self.assert_can_close(user = self.other_user)
@@ -360,8 +360,9 @@ class CloseQuestionPermissionAssertionTests(utils.AskbotTestCase):
         self.assert_can_close(user = self.user)
 
     def test_high_rep_other_can_close(self):
+        self.other_user.set_status('w')
         self.other_user.reputation = self.min_rep
-        self.assert_can_close(user = self.other_user)
+        self.assert_can_close(user=self.other_user)
 
     def test_low_rep_blocked_cannot_close(self):
         self.other_user.set_status('b')
@@ -437,12 +438,13 @@ class ReopenQuestionPermissionAssertionTests(utils.AskbotTestCase):
 
 
     def test_high_rep_nonowner_can_reopen(self):
+        self.other_user.set_status('w')
         self.other_user.reputation = 1000000
-        self.assert_can_reopen(user = self.other_user)
+        self.assert_can_reopen(user=self.other_user)
 
     def test_low_rep_admin_can_reopen(self):
-        self.other_user.set_admin_status()
-        self.assert_can_reopen(user = self.other_user)
+        self.other_user.set_status('d')
+        self.assert_can_reopen(user=self.other_user)
 
     def test_low_rep_moderator_can_reopen(self):
         self.other_user.set_status('m')
@@ -504,13 +506,13 @@ class EditQuestionPermissionAssertionTests(utils.AskbotTestCase):
         self.assert_user_cannot(user = self.other_user)
 
     def test_admin_can_edit(self):
-        self.other_user.set_admin_status()
+        self.other_user.set_status('d')
         self.other_user.save()
         self.assert_other_can()
 
     def test_admin_can_edit_deleted(self):
         self.post.deleted = True
-        self.other_user.set_admin_status()
+        self.other_user.set_status('d')
         self.other_user.save()
         self.assert_other_can()
 
@@ -764,7 +766,7 @@ class FlagOffensivePermissionAssertionTests(PermissionAssertionTestCase):
     def test_admin_has_no_limit_for_flags_per_day(self):
         max_flags = askbot_settings.MAX_FLAGS_PER_USER_PER_DAY
         other_user = self.create_other_user()
-        other_user.set_admin_status()
+        other_user.set_status('d')
         other_user.save()
         for i in range(max_flags + 1):
             question = self.post_question()
@@ -800,11 +802,11 @@ class FlagOffensivePermissionAssertionTests(PermissionAssertionTestCase):
 
     def low_rep_administrator_can_flag(self):
         assert(self.user.reputation < self.min_rep)
-        self.user.set_admin_status()
+        self.user.set_status('d')
         self.assert_user_can_flag()
 
     def test_superuser_cannot_flag_question_twice(self):
-        self.user.set_admin_status()
+        self.user.set_status('d')
         self.user.save()
         self.user.flag_post(post = self.question)
         self.assertRaises(
@@ -822,7 +824,7 @@ class FlagOffensivePermissionAssertionTests(PermissionAssertionTestCase):
         )
 
     def test_superuser_cannot_flag_answer_twice(self):
-        self.user.set_admin_status()
+        self.user.set_status('d')
         self.user.save()
         self.user.flag_post(post = self.answer)
         self.assertRaises(
@@ -1011,7 +1013,7 @@ class CommentPermissionAssertionTests(PermissionAssertionTestCase):
                         parent_post = question,
                         body_text = 'test comment'
                     )
-        self.other_user.set_admin_status()
+        self.other_user.set_status('d')
         self.other_user.save()
         self.other_user.delete_comment(comment)
         self.assertTrue(
@@ -1149,7 +1151,7 @@ class CommentPermissionAssertionTests(PermissionAssertionTestCase):
 
     def test_low_rep_admin_can_comment_others_question(self):
         question = self.post_question()
-        self.other_user.set_admin_status()
+        self.other_user.set_status('d')
         self.other_user.save()
         assert(self.other_user.is_administrator())
         assert(self.other_user.reputation < self.min_rep)
@@ -1191,7 +1193,7 @@ class CommentPermissionAssertionTests(PermissionAssertionTestCase):
         an old timestamp, then posts another comment now
         then user tries to edit the first comment
         """
-        self.other_user.set_admin_status()
+        self.other_user.set_status('d')
         self.other_user.save()
 
         if original_poster is None:
@@ -1225,7 +1227,7 @@ class CommentPermissionAssertionTests(PermissionAssertionTestCase):
 
 
     def test_admin_can_edit_very_old_comment(self):
-        self.user.set_admin_status()
+        self.user.set_status('d')
         self.user.save()
         self.assert_user_can_edit_very_old_comment(original_poster = self.other_user)
 
@@ -1382,20 +1384,20 @@ class AcceptBestAnswerPermissionAssertionTests(utils.AskbotTestCase):
         )
         self.answer.save()
         self.create_user(username = 'third_user')
-        self.third_user.set_admin_status()
+        self.third_user.set_status('d')
         self.third_user.save()
         self.assert_user_can(user = self.third_user)
 
     def test_admin_cannot_accept_own_answer(self):
         self.other_post_answer()
-        self.other_user.set_admin_status()
+        self.other_user.set_status('d')
         self.other_user.save()
         self.assert_user_can(user=self.other_user)
 
     def test_admin_cannot_accept_others_answer_today(self):
         self.other_post_answer()
         self.create_user(username = 'third_user')
-        self.third_user.set_admin_status()
+        self.third_user.set_status('d')
         self.third_user.save()
         self.assert_user_can(user=self.third_user)
 
@@ -1406,7 +1408,7 @@ class AcceptBestAnswerPermissionAssertionTests(utils.AskbotTestCase):
         )
         self.answer.save()
         self.create_user(username = 'third_user')
-        self.third_user.set_admin_status()
+        self.third_user.set_status('d')
         self.third_user.save()
         self.assert_user_can(user = self.third_user)
 
@@ -1563,7 +1565,7 @@ class UploadPermissionAssertionTests(PermissionAssertionTestCase):
 
     def test_low_rep_administrator_can_upload(self):
         assert(self.user.reputation < self.min_rep)
-        self.user.set_admin_status()
+        self.user.set_status('d')
         self.user.save()
         try:
             self.user.assert_can_upload_file()
@@ -1587,25 +1589,25 @@ class ClosedForumTests(utils.AskbotTestCase):
         askbot_settings.update('ASKBOT_CLOSED_FORUM_MODE', False)
 
     @skipIf('askbot.middleware.forum_mode.ForumModeMiddleware' \
-        not in settings.MIDDLEWARE_CLASSES,
+        not in settings.MIDDLEWARE,
         'no ForumModeMiddleware set')
     def test_login_page_accessible(self):
         # futher see in page_load_tests.py
         response = self.client.get(reverse('user_signin'))
-        self.assertEquals(response.status_code, 200)
+        self.assertEqual(response.status_code, 200)
 
     @skipIf('askbot.middleware.forum_mode.ForumModeMiddleware' \
-        not in settings.MIDDLEWARE_CLASSES,
+        not in settings.MIDDLEWARE,
         'no ForumModeMiddleware set')
     def test_anonymous_access(self):
         response = self.client.get(self.test_url)
-        self.assertEquals(response.status_code, 302)
+        self.assertEqual(response.status_code, 302)
         self.assertTrue(self.redirect_to in response['Location'])
 
     @skipIf('askbot.middleware.forum_mode.ForumModeMiddleware' \
-        not in settings.MIDDLEWARE_CLASSES,
+        not in settings.MIDDLEWARE,
         'no ForumModeMiddleware set')
     def test_authenticated_access(self):
         self.client.login(username=self.other_user.username, password=self.password)
         response = self.client.get(self.test_url)
-        self.assertEquals(response.status_code, 200)
+        self.assertEqual(response.status_code, 200)
