@@ -5,7 +5,10 @@ from markdown2 import Markdown
 from django.apps import apps
 from django.contrib.auth.management import create_permissions
 from django.contrib.sites.management import create_default_site
-from django.contrib.contenttypes.management import update_contenttypes
+try:
+    from django.contrib.contenttypes.management import create_contenttypes
+except ImportError: # downwards compatible, Django <1.11
+    from django.contrib.contenttypes.management import update_contenttypes as create_contenttypes
 from django.core.cache import cache
 from django.db.models.signals import post_migrate
 from django.test import TestCase
@@ -26,7 +29,7 @@ def with_settings(**settings_dict):
         def wrapped(*args, **kwargs):
             from askbot.conf import settings as askbot_settings
             backup_settings_dict = dict()
-            for key, value in settings_dict.items():
+            for key, value in list(settings_dict.items()):
                 backup_settings_dict[key] = getattr(askbot_settings, key)
                 askbot_settings.update(key, value)
 
@@ -35,7 +38,7 @@ def with_settings(**settings_dict):
             except:
                 raise
             finally:
-                for key, value in backup_settings_dict.items():
+                for key, value in list(backup_settings_dict.items()):
                     askbot_settings.update(key, value)
 
         return wrapped
@@ -84,7 +87,7 @@ def create_user(username=None,
     #because just below we will be replacing them with the new values
     user.notification_subscriptions.all().delete()
 
-    for feed_type, frequency in notification_schedule.items():
+    for feed_type, frequency in list(notification_schedule.items()):
         feed = models.EmailFeedSetting(
                         feed_type = feed_type,
                         frequency = frequency,
@@ -107,18 +110,18 @@ class AskbotTestCase(TestCase):
     def _fixture_setup(self):
         super(AskbotTestCase, self)._fixture_setup()
         for app_config in apps.get_app_configs():
-            update_contenttypes(app_config)
+            create_contenttypes(app_config)
             create_permissions(app_config)
             create_default_site(app_config)
 
     def _fixture_teardown(self):
         post_migrate.disconnect(create_default_site, sender=apps.get_app_config('sites'))
-        post_migrate.disconnect(update_contenttypes)
+        post_migrate.disconnect(create_contenttypes)
         post_migrate.disconnect(create_permissions, dispatch_uid="django.contrib.auth.management.create_permissions")
 
         super(AskbotTestCase, self)._fixture_teardown()
 
-        post_migrate.connect(update_contenttypes)
+        post_migrate.connect(create_contenttypes)
         post_migrate.connect(create_permissions, dispatch_uid="django.contrib.auth.management.create_permissions")
         post_migrate.connect(create_default_site, sender=apps.get_app_config('sites'))
 
@@ -166,7 +169,7 @@ class AskbotTestCase(TestCase):
         """a shim for python < 2.7"""
         try:
             #run assertRaisesRegex, if available
-            super(AskbotTestCase, self).assertRaisesRegexp(*args, **kwargs)
+            super(AskbotTestCase, self).assertRaisesRegex(*args, **kwargs)
         except AttributeError:
             #in this case lose testing for the error text
             #second argument is the regex that is supposed
@@ -175,14 +178,6 @@ class AskbotTestCase(TestCase):
             args_list.pop(1)#so we can remove an item
             self.assertRaises(*args_list, **kwargs)
 
-    def assertQuerysetEqual(self, qs1, qs2, transform=repr, ordered=True):
-        '''borrowed from django1.4 and modified a bit'''
-        items = map(transform, qs1)
-        values = map(transform, qs2)
-        if not ordered:
-            return self.assertEqual(set(items), set(values))
-        return self.assertEqual(list(items), list(values))
-
     def post_question(
                     self,
                     user=None,
