@@ -592,79 +592,78 @@ urlpatterns = [
         views.commands.join_or_leave_group,
         name='join_or_leave_group'
     ),
-    # widgets url!
-    service_url(
-        r'^%s$' % (pgettext('urls', 'widgets/')),
-        views.widgets.widgets,
-        name='widgets'
-    ),
-    service_url(
-        r'^%s%s(?P<widget_id>\d+)/$' % (
-            pgettext('urls', 'widgets/'),
-            pgettext('urls', 'ask/')
-        ),
-        views.widgets.ask_widget,
-        name='ask_by_widget'
-    ),
-    service_url(
-        r'^%s%s(?P<widget_id>\d+).js$' % (
-            pgettext('urls', 'widgets/'),
-            pgettext('urls', 'ask/')
-        ),
-        views.widgets.render_ask_widget_js,
-        name='render_ask_widget'
-    ),
-    service_url(
-        r'^%s%s(?P<widget_id>\d+).css$' % (
-            pgettext('urls', 'widgets/'),
-            pgettext('urls', 'ask/')
-        ),
-        views.widgets.render_ask_widget_css,
-        name='render_ask_widget_css'
-    ),
-    service_url(
-        r'^%s%s%s$' % (
-            pgettext('urls', 'widgets/'),
-            pgettext('urls', 'ask/'),
-            pgettext('urls', 'complete/')
-        ),
-        views.widgets.ask_widget_complete,
-        name='ask_by_widget_complete'
-    ),
-    service_url(
-        r'^%s(?P<model>\w+)/%s$' % (
-            pgettext('urls', 'widgets/'),
-            pgettext('urls', 'create/')
-        ),
-        views.widgets.create_widget,
-        name='create_widget'
-    ),
-    service_url(
-        r'^%s(?P<model>\w+)/%s(?P<widget_id>\d+)/$' % (
-            pgettext('urls', 'widgets/'),
-            pgettext('urls', 'edit/')
-        ),
-        views.widgets.edit_widget,
-        name='edit_widget'
-    ),
-    service_url(
-        r'^%s(?P<model>\w+)/%s(?P<widget_id>\d+)/$' % (
-            pgettext('urls', 'widgets/'),
-            pgettext('urls', 'delete/')
-        ),
-        views.widgets.delete_widget,
-        name='delete_widget'
-    ),
-    service_url(
-        r'^%s(?P<model>\w+)/$' % (pgettext('urls', 'widgets/')),
-        views.widgets.list_widgets,
-        name='list_widgets'
-    ),
-    service_url(
-        r'^widgets/%s(?P<widget_id>\d+)/$' % MAIN_PAGE_BASE_URL,
-        views.widgets.question_widget,
-        name='question_widget'
-    ),
+#    service_url(
+#        r'^%s$' % (pgettext('urls', 'widgets/')),
+#        views.widgets.widgets,
+#        name='widgets'
+#    ),
+#    service_url(
+#        r'^%s%s(?P<widget_id>\d+)/$' % (
+#            pgettext('urls', 'widgets/'),
+#            pgettext('urls', 'ask/')
+#        ),
+#        views.widgets.ask_widget,
+#        name='ask_by_widget'
+#    ),
+#    service_url(
+#        r'^%s%s(?P<widget_id>\d+).js$' % (
+#            pgettext('urls', 'widgets/'),
+#            pgettext('urls', 'ask/')
+#        ),
+#        views.widgets.render_ask_widget_js,
+#        name='render_ask_widget'
+#    ),
+#    service_url(
+#        r'^%s%s(?P<widget_id>\d+).css$' % (
+#            pgettext('urls', 'widgets/'),
+#            pgettext('urls', 'ask/')
+#        ),
+#        views.widgets.render_ask_widget_css,
+#        name='render_ask_widget_css'
+#    ),
+#    service_url(
+#        r'^%s%s%s$' % (
+#            pgettext('urls', 'widgets/'),
+#            pgettext('urls', 'ask/'),
+#            pgettext('urls', 'complete/')
+#        ),
+#        views.widgets.ask_widget_complete,
+#        name='ask_by_widget_complete'
+#    ),
+#    service_url(
+#        r'^%s(?P<model>\w+)/%s$' % (
+#            pgettext('urls', 'widgets/'),
+#            pgettext('urls', 'create/')
+#        ),
+#        views.widgets.create_widget,
+#        name='create_widget'
+#    ),
+#    service_url(
+#        r'^%s(?P<model>\w+)/%s(?P<widget_id>\d+)/$' % (
+#            pgettext('urls', 'widgets/'),
+#            pgettext('urls', 'edit/')
+#        ),
+#        views.widgets.edit_widget,
+#        name='edit_widget'
+#    ),
+#    service_url(
+#        r'^%s(?P<model>\w+)/%s(?P<widget_id>\d+)/$' % (
+#            pgettext('urls', 'widgets/'),
+#            pgettext('urls', 'delete/')
+#        ),
+#        views.widgets.delete_widget,
+#        name='delete_widget'
+#    ),
+#    service_url(
+#        r'^%s(?P<model>\w+)/$' % (pgettext('urls', 'widgets/')),
+#        views.widgets.list_widgets,
+#        name='list_widgets'
+#    ),
+#    service_url(
+#        r'^widgets/%s(?P<widget_id>\d+)/$' % MAIN_PAGE_BASE_URL,
+#        views.widgets.question_widget,
+#        name='question_widget'
+#    ),
     service_url(
         r'^get-perms-data/$',
         views.readers.get_perms_data,
