@@ -2,7 +2,7 @@
 import os
 import random
 import time
-import urlparse
+import urllib.parse
 from django.core.files.storage import get_storage_class
 from django.conf import settings as django_settings
 
@@ -15,15 +15,6 @@ def make_file_name(ext, prefix=''):
     return prefix + name + ext
 
 
-def read_file_chunkwise(file_obj, chunk_size=32768):
-    """Iterates over the file and yields chunks of contents"""
-    while True:
-        data = file_obj.read(chunk_size)
-        if not data:
-            break
-        yield data
-
-
 def store_file(file_object, file_name_prefix = ''):
     """Creates an instance of django's file storage
     object based on the file-like object,
@@ -36,9 +27,9 @@ def store_file(file_object, file_name_prefix = ''):
     file_storage.save(file_name, file_object)
 
     file_url = file_storage.url(file_name)
-    parsed_url = urlparse.urlparse(file_url)
-    file_url = urlparse.urlunparse(
-        urlparse.ParseResult(
+    parsed_url = urllib.parse.urlparse(file_url)
+    file_url = urllib.parse.urlunparse(
+        urllib.parse.ParseResult(
             parsed_url.scheme,
             parsed_url.netloc,
             parsed_url.path,
