@@ -10,7 +10,7 @@ from bs4 import BeautifulSoup
 from django.conf import settings as django_settings
 from django.core import exceptions
 #from django.core.management import call_command
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.contrib.auth.decorators import login_required
 from django.http import Http404
 from django.http import HttpResponse
@@ -22,14 +22,13 @@ from django.shortcuts import get_object_or_404
 from django.shortcuts import render
 from django.template.loader import get_template
 from django.views.decorators import csrf
-import simplejson
+import json
 from django.utils import timezone
 from django.utils import translation
 from django.utils.encoding import force_text
 from django.utils.html import escape
 from django.utils.translation import ugettext as _
 from django.utils.translation import ungettext
-from django.utils.translation import string_concat
 from askbot.utils.slug import slugify
 from askbot import models
 from askbot import forms
@@ -45,8 +44,8 @@ from askbot.utils.functions import decode_and_loads
 from askbot.utils.html import get_login_link
 from askbot.utils.akismet_utils import akismet_check_spam
 from django.template import RequestContext
-from askbot.skins.loaders import render_into_skin_as_string
-from askbot.skins.loaders import render_text_into_skin
+from askbot.skins.shortcuts import render_into_skin_as_string
+from askbot.skins.shortcuts import render_text_into_skin
 from askbot.models.tag import get_tags_by_names
 
 
@@ -60,7 +59,7 @@ def process_vote(user = None, vote_direction = None, post = None):
     also in the future make keys in response data be more meaningful
     right now they are kind of cryptic - "status", "count"
     """
-    if user.is_anonymous():
+    if user.is_anonymous:
         raise exceptions.PermissionDenied(_(
             'Sorry, anonymous users cannot vote'
         ))
@@ -155,7 +154,7 @@ def vote(request):
         if not request.is_ajax() or not request.method == 'POST':
             raise Exception(_('Sorry, something is not right here...'))
 
-        if not request.user.is_authenticated():
+        if not request.user.is_authenticated:
             raise exceptions.PermissionDenied(
                 _('Sorry, but anonymous users cannot perform this action.'))
 
@@ -204,10 +203,10 @@ def vote(request):
         if vote_type in const.VOTE_TYPES_INVALIDATE_CACHE:
             post.thread.reset_cached_data()
     except Exception as e:
-        response_data['message'] = unicode(e)
+        response_data['message'] = str(e)
         response_data['success'] = 0
 
-    data = simplejson.dumps(response_data)
+    data = json.dumps(response_data)
     return HttpResponse(data, content_type='application/json')
 
 #internally grouped views - used by the tagging system
@@ -216,7 +215,7 @@ def vote(request):
 @decorators.post_only
 def mark_tag(request, **kwargs):#tagging system
 
-    if request.user.is_anonymous():
+    if request.user.is_anonymous:
         msg = _('anonymous users cannot %(perform_action)s') % \
             {'perform_action': _('mark or unmark tags')}
         raise exceptions.PermissionDenied(msg + ' ' + get_login_link())
@@ -269,7 +268,7 @@ def mark_tag(request, **kwargs):#tagging system
 def clean_tag_name(request):
     tag_name = forms.clean_tag(request.POST['tag_name'])
     return {'cleaned_tag_name': tag_name}
-    
+
 
 #@decorators.ajax_only
 @decorators.get_only
@@ -284,7 +283,7 @@ def get_tags_by_wildcard(request):
     matching_tags = models.Tag.objects.get_by_wildcards( [wildcard,] )
     count = matching_tags.count()
     names = matching_tags.values_list('name', flat = True)[:20]
-    re_data = simplejson.dumps({'tag_count': count, 'tag_names': list(names)})
+    re_data = json.dumps({'tag_count': count, 'tag_names': list(names)})
     return HttpResponse(re_data, content_type='application/json')
 
 @decorators.get_only
@@ -298,7 +297,7 @@ def get_thread_shared_users(request):
         'users': users,
     }
     html = render_into_skin_as_string('widgets/user_list.html', data, request)
-    re_data = simplejson.dumps({
+    re_data = json.dumps({
         'html': html,
         'users_count': users.count(),
         'success': True
@@ -314,7 +313,7 @@ def get_thread_shared_groups(request):
     groups = thread.get_groups_shared_with()
     data = {'groups': groups}
     html = render_into_skin_as_string('widgets/groups_list.html', data, request)
-    re_data = simplejson.dumps({
+    re_data = json.dumps({
         'html': html,
         'groups_count': groups.count(),
         'success': True
@@ -324,7 +323,7 @@ def get_thread_shared_groups(request):
 @decorators.ajax_only
 def get_html_template(request):
     """returns rendered template"""
-    template_name = request.REQUEST.get('template_name', None)
+    template_name = getattr(request,request.method).get('template_name', None)
     allowed_templates = (
         'widgets/tag_category_selector.html',
     )
@@ -380,7 +379,7 @@ def save_object_description(request):
 @decorators.ajax_only
 @decorators.post_only
 def rename_tag(request):
-    if request.user.is_anonymous() \
+    if request.user.is_anonymous \
         or not request.user.is_administrator_or_moderator():
         raise exceptions.PermissionDenied()
     post_data = decode_and_loads(request.body)
@@ -406,7 +405,7 @@ def rename_tag(request):
 def delete_tag(request):
     """todo: actually delete tags
     now it is only deletion of category from the tree"""
-    if request.user.is_anonymous() \
+    if request.user.is_anonymous \
         or not request.user.is_administrator_or_moderator():
         raise exceptions.PermissionDenied()
 
@@ -440,7 +439,7 @@ def add_tag_category(request):
     todo: switch to json stored in the live settings
     now we have indented input
     """
-    if request.user.is_anonymous() \
+    if request.user.is_anonymous \
         or not request.user.is_administrator_or_moderator():
         raise exceptions.PermissionDenied()
 
@@ -479,9 +478,9 @@ def get_groups_list(request):
 def subscribe_for_tags(request):
     """process subscription of users by tags"""
     #todo - use special separator to split tags
-    tag_names = request.REQUEST.get('tags','').strip().split()
+    tag_names = getattr(request,request.method).get('tags','').strip().split()
     pure_tag_names, wildcards = forms.clean_marked_tagnames(tag_names)
-    if request.user.is_authenticated():
+    if request.user.is_authenticated:
         if request.method == 'POST':
             if 'ok' in request.POST:
                 request.user.mark_tags(
@@ -496,7 +495,7 @@ def subscribe_for_tags(request):
             else:
                 message = _(
                     'Tag subscription was canceled (<a href="%(url)s">undo</a>).'
-                ) % {'url': escape(request.path) + '?tags=' + request.REQUEST['tags']}
+                ) % {'url': escape(request.path) + '?tags=' + getattr(request,request.method)['tags']}
                 request.user.message_set.create(message = message)
             return HttpResponseRedirect(reverse('index'))
         else:
@@ -613,7 +612,7 @@ def edit_bulk_tag_subscription(request, pk):
 def toggle_follow_question(request):
     result = dict()
 
-    if request.user.is_anonymous():
+    if request.user.is_anonymous:
         msg = _('anonymous users cannot %(perform_action)s') % \
             {'perform_action': askbot_settings.WORDS_FOLLOW_QUESTIONS}
         raise exceptions.PermissionDenied(msg + ' ' + get_login_link())
@@ -629,7 +628,7 @@ def toggle_follow_question(request):
 @decorators.ajax_only
 @decorators.post_only
 def set_question_title(request):
-    if request.user.is_anonymous():
+    if request.user.is_anonymous:
         message = _('anonymous users cannot %(perform_action)s') % \
             {'perform_action': _('make edits')}
         raise exceptions.PermissionDenied(message)
@@ -668,7 +667,7 @@ def get_post_body(request):
 @decorators.post_only
 def set_post_body(request):
     """Updates text body of post"""
-    if request.user.is_anonymous():
+    if request.user.is_anonymous:
         message = _('anonymous users cannot %(perform_action)s') % \
             {'perform_action': _('make edits')}
         raise exceptions.PermissionDenied(message)
@@ -731,7 +730,7 @@ def api_get_questions(request):
         except:
             continue
 
-    json_data = simplejson.dumps(thread_list)
+    json_data = json.dumps(thread_list)
     return HttpResponse(json_data, content_type="application/json")
 
 
@@ -784,7 +783,7 @@ def close(request, id):#close question
             }
             return render(request, 'close.html', data)
     except exceptions.PermissionDenied as e:
-        request.user.message_set.create(message = unicode(e))
+        request.user.message_set.create(message = str(e))
         return HttpResponseRedirect(question.get_absolute_url())
 
 @login_required
@@ -814,7 +813,7 @@ def reopen(request, id):#re-open question
             return render(request, 'reopen.html', data)
 
     except exceptions.PermissionDenied as e:
-        request.user.message_set.create(message = unicode(e))
+        request.user.message_set.create(message = str(e))
         return HttpResponseRedirect(question.get_absolute_url())
 
 
@@ -822,7 +821,7 @@ def reopen(request, id):#re-open question
 @decorators.ajax_only
 @decorators.post_only
 def upvote_comment(request):
-    if request.user.is_anonymous():
+    if request.user.is_anonymous:
         raise exceptions.PermissionDenied(_('Please sign in to vote'))
     form = forms.VoteForm(request.POST)
     if form.is_valid():
@@ -843,7 +842,7 @@ def upvote_comment(request):
 @decorators.ajax_only
 @decorators.post_only
 def delete_post(request):
-    if request.user.is_anonymous():
+    if request.user.is_anonymous:
         raise exceptions.PermissionDenied(_('Please sign in to delete/restore posts'))
     form = forms.VoteForm(request.POST)
     if form.is_valid():
@@ -867,7 +866,7 @@ def read_message(request):#marks message a read
     if request.method == "POST":
         if request.POST.get('formdata') == 'required':
             request.session['message_silent'] = 1
-            if request.user.is_authenticated():
+            if request.user.is_authenticated:
                 request.user.delete_messages()
     return HttpResponse('')
 
@@ -1015,9 +1014,9 @@ def set_group_openness(request):
 @decorators.ajax_only
 @decorators.moderators_only
 def edit_object_property_text(request):
-    model_name = CharField().clean(request.REQUEST['model_name'])
-    object_id = IntegerField().clean(request.REQUEST['object_id'])
-    property_name = CharField().clean(request.REQUEST['property_name'])
+    model_name = CharField().clean(getattr(request,request.method)['model_name'])
+    object_id = IntegerField().clean(getattr(request,request.method)['object_id'])
+    property_name = CharField().clean(getattr(request,request.method)['property_name'])
 
     accessible_fields = (
         ('Group', 'preapproved_emails'),
@@ -1048,7 +1047,7 @@ def join_or_leave_group(request):
 
     returns resulting "membership_level"
     """
-    if request.user.is_anonymous():
+    if request.user.is_anonymous:
         raise exceptions.PermissionDenied()
 
     Group = models.Group
@@ -1163,7 +1162,7 @@ def moderate_suggested_tag(request):
 def save_draft_question(request):
     """saves draft questions"""
     #todo: maybe allow drafts for anonymous users
-    if request.user.is_anonymous() \
+    if request.user.is_anonymous \
         or request.user.is_read_only() \
         or askbot_settings.READ_ONLY_MODE_ENABLED \
         or request.user.is_active == False \
@@ -1195,7 +1194,7 @@ def save_draft_question(request):
 def save_draft_answer(request):
     """saves draft answers"""
     #todo: maybe allow drafts for anonymous users
-    if request.user.is_anonymous() \
+    if request.user.is_anonymous \
         or request.user.is_read_only() \
         or askbot_settings.READ_ONLY_MODE_ENABLED \
         or request.user.is_active == False \
@@ -1228,7 +1227,7 @@ def get_users_info(request):
     """retuns list of user names and email addresses
     of "fake" users - so that admins can post on their
     behalf"""
-    if request.user.is_anonymous():
+    if request.user.is_anonymous:
         return HttpResponseForbidden()
 
     query = request.GET['q']
@@ -1367,7 +1366,7 @@ def get_editor(request):
     """
     if 'config' not in request.GET:
         return HttpResponseForbidden()
-    config = simplejson.loads(request.GET['config'])
+    config = json.loads(request.GET['config'])
     element_id = request.GET.get('id', 'editor')
     form = forms.EditorForm(
                 attrs={'id': element_id},
@@ -1395,7 +1394,7 @@ def get_editor(request):
         'scripts': parsed_scripts,
         'success': True
     }
-    return HttpResponse(simplejson.dumps(data), content_type='application/json')
+    return HttpResponse(json.dumps(data), content_type='application/json')
 
 @csrf.csrf_protect
 @decorators.ajax_only
@@ -1405,7 +1404,7 @@ def publish_answer(request):
     current thread is moderated
     """
     denied_msg = _('Sorry, only thread moderators can use this function')
-    if request.user.is_authenticated():
+    if request.user.is_authenticated:
         if request.user.is_administrator_or_moderator() is False:
             raise exceptions.PermissionDenied(denied_msg)
     #todo: assert permission
@@ -1433,7 +1432,7 @@ def publish_answer(request):
 @decorators.post_only
 def merge_questions(request):
     post_data = decode_and_loads(request.body)
-    if request.user.is_anonymous():
+    if request.user.is_anonymous:
         denied_msg = _('Sorry, only thread moderators can use this function')
         raise exceptions.PermissionDenied(denied_msg)
 
@@ -1452,7 +1451,7 @@ def translate_url(request):
     form = forms.TranslateUrlForm(request.GET)
     match = None
     if form.is_valid():
-        from django.core.urlresolvers import resolve, Resolver404, NoReverseMatch
+        from django.urls import resolve, Resolver404, NoReverseMatch
         try:
             match = resolve(form.cleaned_data['url'])
         except Resolver404:
@@ -1464,7 +1463,8 @@ def translate_url(request):
         site_lang = translation.get_language()
         translation.activate(lang)
 
-        if match.url_name == 'questions' and None in match.kwargs.values():
+        if match.url_name == 'questions' and None in list(match.kwargs.values()):
+            #???
             url = models.get_feed_url(match.kwargs['feed'])
         else:
             try:
@@ -1481,9 +1481,9 @@ def translate_url(request):
 @decorators.post_only
 def reorder_badges(request):
     """places given badge to desired position"""
-    if request.user.is_anonymous() \
+    if request.user.is_anonymous \
         or not request.user.is_administrator_or_moderator():
-        raise exceptions.PermisionDenied()
+        raise exceptions.PermissionDenied()
 
     form = forms.ReorderBadgesForm(request.POST)
     if form.is_valid():
@@ -1491,7 +1491,7 @@ def reorder_badges(request):
         position = form.cleaned_data['position']
         badge = models.BadgeData.objects.get(id=badge_id)
         badges = list(models.BadgeData.objects.all())
-        badges = filter(lambda v: v.is_enabled(), badges)
+        badges = [v for v in badges if v.is_enabled()]
         badges.remove(badge)
         badges.insert(position, badge)
         pos = 0
